function objval = Prog_MainSS_A11(option,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,taux,omega,distoff)

% note: the only purpose of option is that replication can be done without manual work; so the numbering of option is not intuitive at all

title = sprintf( '______________________________ Compute the Steady State Equilibrium ______________________________ ');
disp(title)

nh = 36;            % HK grid for value, decision
nh_dist = 500;      % HK grid for distribution
hhigh0 = 15;        % make sure to check if simulated data do not go over this limit

% Policy option: Means-tested pronatal transfers income cut
inccut = 0.81;      % sum(incsim<inccut)/NS => In Baseline experiment with omega=0.02, 50% threshold

% For shutting down externality
hbarhat = 5.783218901406690;

pct_target = 0.85;     % 0.85 = top 15%

sigma = 0.5;   % not used
A = 1.0;
Yss = 1.0;
alpha2 = 0;   % not used
psicmean = 1;

% meta parameters
tol = 1e-4;
toldist = 1e-6;
tolout = 1e-4;
damph = 0.0;   % dampening parameter 

nn = 4;      % maximum number of children - 1
nk = 20;     % number of grid for kappa
npsi = 20;   % number of grid for psi
nt = 50;     % number of grid for time; chosen to be large enough to get stable results

ngrid = linspace(0,nn-1,nn);     % grid for number of children 0,1,...

% custermized grid
tgrid = zeros(1,nt);
nt0 = round(nt*0.9);
tgrid(1,1:nt0) = linspace(tol,0.7,nt0);
tgrid(1,nt0:nt) = linspace(0.7,1,nt-nt0+1);

% log normal distribution
[kappagrid, kappaprmat] = tauchen(0,kappasd,kapparho,3,nk);
kappagrid = exp(kappagrid);

[psicgrid, prpsic] = tauchen(0,psicsd,0,3,npsi);
psicgrid = exp(psicgrid)*psicmean;
prpsic = prpsic(1,:);

% non-parametric utility along quantity
phigrid = zeros(nn,1);
phigrid(2) = phi1;
phigrid(3) = phi1+phi2add;
phigrid(4) = phi1+phi2add+phi3add;

hlow = max(0.5,HKprodfn(Ah*kappagrid(1),0,0,theta0,alpha1,alpha2));

hhigh = Yss*hhigh0;
hgrid = gengrid(hlow,hhigh,nh,2,2.0);
hgrid_dist = linspace(hlow,hhigh,nh_dist);

NS = 500000;   % number of simulated samples

% initialization
Vmat = zeros(nh,npsi,nk,nn);
cmat = zeros(nh,npsi,nk,nn);
lmat = zeros(nh,npsi,nk,nn);
hwmat = zeros(nh,npsi,nk,nn);
xmat = zeros(nh,npsi,nk,nn);

nindmat = zeros(nh,npsi,nk);
nmat = zeros(nh,npsi,nk);

nindmat_dist = zeros(nh_dist,npsi,nk);

% initial guess for L
L = Yss;

% Outer loop: find equilibrium prices
startsol = tic;

iterationout = 1; distanceout = 10000;

T = 0;

% initial guess
Hmean = L*3;
H15 = L*5.5;

% initial distribution
mumatpre = ones(nh_dist,nk)/(nh_dist*nk);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%           OUTER LOOP            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

while distanceout > tolout
    startIterout = tic;
    w = A;

    i0 = sprintf ( 'H15 =%8.2f     Hmean = %8.2f     hhigh = %8.2f    hlow = %8.2f', H15, Hmean, hhigh, hlow);
    disp(i0)


    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%           INNER LOOP            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Find the expectation-consistent distribution

    iteration = 1; distance = 10000;

    while distance > toldist
        startIter = tic;

        %%%%%%%%%%%%%%%%%%%%%%%%%%
        % Computing value functions and decision rules
        % Conditional on having no child (n=0)
        in = 1;
        nnow = ngrid(in);
        parfor ih = 1:nh
            hpnow = hgrid(ih);
            for ib = 1:npsi
                psic = psicgrid(ib);
                for jk = 1:nk
                    kappanow = kappagrid(jk);

                    lmax = 1;

                    if (w*hpnow*lmax > T)

                        nt0 = sum(tgrid<=lmax);

                        objpos = @(les) ( psic*log(HES(w*hpnow*(lmax-les) + T,0)) + psil*((les)^(1-gamma))/(1-gamma) );

                        vvectemp = zeros(nt0,1);
                        for it = 1:nt0
                            if isreal(objpos(tgrid(it)))==1
                                vvectemp(it) = objpos(tgrid(it));
                            else
                                vvectemp(it) = -inf;
                            end
                        end

                        [Nval, minind] = max(vvectemp);  % maximizing objective fn

                        lmat(ih,ib,jk,in) = tgrid(minind);
                        hwmat(ih,ib,jk,in) = lmax - tgrid(minind);
                        Vmat(ih,ib,jk,in) = Nval;
                        cmat(ih,ib,jk,in) = w*hpnow*hwmat(ih,ib,jk,in) + T;

                        xmat(ih,ib,jk,in) = 0;

                    else
                        % work full time but cannot afford positive consumption (due to lump-sum tax)
                        Vmat(ih,ib,jk,in) = -inf;
                    end

                end
            end
        end



        parfor ih = 1:nh
            hpnow = hgrid(ih);
            for in = 2:nn
                nnow = ngrid(in);
                phinow = phigrid(in);
                for ib = 1:npsi
                    psic = psicgrid(ib);
                    for jk = 1:nk
                        kappanow = kappagrid(jk);

                        if (distoff==1)
                            htilde = hbarhat;
                        else
                            htilde = H15;
                        end

                        % Conditional on having positive no. of children (n>0)

                        lmax = 1 - lambda*nnow;

                        nt0 = sum(tgrid<=lmax);

                        if (qualutil10(HKprodfn(Ah*kappanow,hpnow,0,theta0,alpha1,alpha2),htilde,chi,sigma)>-inf)
                            xmin = 0;
                        else
                            xmin = max( (((chi*htilde)/(Ah*kappanow) - theta0)^(1/alpha1))*(hpnow^(-alpha2/alpha1)), 0);
                        end

                        % case 1: interior x > xmin
                        vvectemp1 = zeros(nt0,1);
                        cvectemp1 = zeros(nt0,1);

                        for it = 1:nt0
                            if (w*hpnow*(lmax-tgrid(it))<inccut)
                                Trntemp = Trn(omega,nnow);
                            else
                                Trntemp = 0;
                            end

                            cmax = w*hpnow*(lmax-tgrid(it)) + T + Trntemp - (1+taux)*xmin*nnow;

                            if (cmax <= 0)
                                vvectemp1(it) = -inf;
                            else
                                objneg1 = @(c) - ( psic*log(HES(c, nnow)) + psil*(tgrid(it)^(1-gamma))/(1-gamma) ...
                                    + phinow*qualutil10(HKprodfn(Ah*kappanow,hpnow,(w*hpnow*(lmax-tgrid(it)) + T + Trntemp - c )/((1+taux)*nnow),theta0,alpha1,alpha2),htilde,chi,sigma) );

                                cvectemp1(it) = GSS(objneg1,0,cmax,tol);
                                vvectemp1(it) = -objneg1(cvectemp1(it));
                            end
                        end

                        [Vval1, maxind1] = max(vvectemp1);  % maximizing over values

                        % case 2: x = xmin
                        vvectemp2 = zeros(nt0,1);

                        for it = 1:nt0
                            if (w*hpnow*(lmax-tgrid(it))<inccut)
                                Trntemp = Trn(omega,nnow);
                            else
                                Trntemp = 0;
                            end

                            cmax = w*hpnow*(lmax-tgrid(it)) + T + Trntemp - (1+taux)*xmin*nnow;

                            objpos2 = @(les) ( psic*log(HES(w*hpnow*(lmax-les) + T + Trntemp - (1+taux)*xmin*nnow,nnow)) + psil*((les)^(1-gamma))/(1-gamma) ...
                                + phinow*qualutil10(HKprodfn(Ah*kappanow,hpnow,xmin,theta0,alpha1,alpha2),htilde,chi,sigma) );

                            if (cmax <= 0)
                                vvectemp2(it) = -inf;
                            else
                                vvectemp2(it) = objpos2(tgrid(it));
                            end
                        end

                        [Vval2, maxind2] = max(vvectemp2);  % maximizing objective fn

                        if (isreal(Vval1)==0) && (isreal(Vval2)==0)
                            lmat(ih,ib,jk,in) = 0;
                            hwmat(ih,ib,jk,in) = 0;
                            xmat(ih,ib,jk,in) = 0;
                            cmat(ih,ib,jk,in) = 0;
                            Vmat(ih,ib,jk,in) = -inf;

                        elseif (Vval1>Vval2)
                            lmat(ih,ib,jk,in) = tgrid(maxind1);
                            hwmat(ih,ib,jk,in) = lmax - tgrid(maxind1);
                            if (w*hpnow*(lmax-tgrid(maxind1))<inccut)
                                Trntemp = Trn(omega,nnow);
                            else
                                Trntemp = 0;
                            end
                            xmat(ih,ib,jk,in) = (w*hpnow*(lmax-tgrid(maxind1)) + T + Trntemp - cvectemp1(maxind1) )/((1+taux)*nnow);
                            cmat(ih,ib,jk,in) = cvectemp1(maxind1);
                            Vmat(ih,ib,jk,in) = Vval1;
                        else
                            lmat(ih,ib,jk,in) = tgrid(maxind2);
                            hwmat(ih,ib,jk,in) = lmax - tgrid(maxind2);
                            xmat(ih,ib,jk,in) = xmin;
                            if (w*hpnow*(lmax-tgrid(maxind2))<inccut)
                                Trntemp = Trn(omega,nnow);
                            else
                                Trntemp = 0;
                            end
                            cmat(ih,ib,jk,in) = w*hpnow*(lmax-tgrid(maxind2)) + T + Trntemp - (1+taux)*xmin*nnow;
                            Vmat(ih,ib,jk,in) = Vval2;
                        end

                    end
                end
            end
        end


        % Obtain expected utility
        % expectation w.r.t. productivity
        EVtemp = zeros(nh,npsi,nk,nn);
        for ih = 1:nh
            for ib = 1:npsi
                for in = 1:nn
                    for ik = 1:nk
                        EVtempval = 0;
                        for jk = 1:nk
                            EVtempval = EVtempval + kappaprmat(ik,jk)*Vmat(ih,ib,jk,in);
                        end
                        EVtemp(ih,ib,ik,in) = EVtempval;
                    end
                end
            end
        end

        EVmat = EVtemp;

        % Fertility decision
        for ih = 1:nh
            for ib = 1:npsi
                for ik = 1:nk
                    [~, nindmat(ih,ib,ik)] = max(EVmat(ih,ib,ik,:));
                    nmat(ih,ib,ik) = ngrid(nindmat(ih,ib,ik));
                end
            end
        end

        if (sum(nmat)==0)
            disp(' !! Warning: nobody wants to have kids !!')
        end

        %%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % stationary distribution

        % conditional on being able to have kid + ability draw
        jhmat = zeros(nh_dist,npsi,nk,nk);
        whmat = zeros(nh_dist,npsi,nk,nk);

        mumatpre0 = mumatpre;

        iteration0 = 1;   distance0 = 10000;
        while distance0 > toldist
            Tmumatpre = zeros(nh_dist,nk);

            parfor ih_dist = 1:nh_dist
                hpnow = hgrid_dist(ih_dist);
                for ik = 1:nk
                    for ib = 1:npsi
                        % 1. fertility
                        % obtain conditional values on hgrid_dist
                        valvectemp = zeros(nn,1);
                        for in = 1:nn
                            valvectemp(in,1) = lini(hgrid,EVmat(:,ib,ik,in),hpnow);
                        end
                        % find maximum index for n choice
                        [~ , maxindn] = max(valvectemp);
                        nindmat_dist(ih_dist,ib,ik) = maxindn;

                        for jk = 1:nk
                            kappakid = kappagrid(jk);
                            % 2. private education spending
                            xtemp = lini(hgrid,xmat(:,ib,jk,maxindn),hpnow);

                            % 3. then find implied h'       
                            hnexttemp = HKprodfn(Ah*kappakid,hpnow,xtemp,theta0,alpha1,alpha2);

                            % finding indices and weights
                            if hnexttemp <= hgrid_dist(1)
                                jhmat(ih_dist,ib,ik,jk) = 1;
                                whmat(ih_dist,ib,ik,jk) = 1;

                            elseif hnexttemp >= hgrid_dist(nh_dist)
                                jhmat(ih_dist,ib,ik,jk) = nh_dist - 1;
                                whmat(ih_dist,ib,ik,jk) = 0;

                            else
                                jhmat(ih_dist,ib,ik,jk) = sum(hgrid_dist<hnexttemp);
                                whmat(ih_dist,ib,ik,jk) = (hgrid_dist(jhmat(ih_dist,ib,ik,jk)+1) - hnexttemp)/(hgrid_dist(jhmat(ih_dist,ib,ik,jk)+1) - hgrid_dist(jhmat(ih_dist,ib,ik,jk)));

                            end

                        end
                    end
                end
            end


            for ih_dist = 1:nh_dist
                for ik = 1:nk
                    if mumatpre0(ih_dist,ik) > 0
                        for ib = 1:npsi
                            muval = mumatpre0(ih_dist,ik)*prpsic(ib);
                            % shocks realized
                            for jk = 1:nk
                                jh = jhmat(ih_dist,ib,ik,jk);
                                wgt_hnext = whmat(ih_dist,ib,ik,jk);
                                Tmumatpre(jh,jk) = Tmumatpre(jh,jk) + kappaprmat(ik,jk)*wgt_hnext*ngrid(nindmat_dist(ih_dist,ib,ik))*muval;
                                Tmumatpre(jh+1,jk) = Tmumatpre(jh+1,jk) + kappaprmat(ik,jk)*(1-wgt_hnext)*ngrid(nindmat_dist(ih_dist,ib,ik))*muval;
                            end
                        end
                    end
                end
            end

            musum = sum(mumatpre0(:));

            mumat0 = zeros(nh_dist,npsi,nk);
            for ih_dist = 1:nh_dist
                for ik = 1:nk
                    for ib = 1:npsi
                        mumat0(ih_dist,ib,ik) = prpsic(ib)*mumatpre0(ih_dist,ik);
                    end
                end
            end

            % scaling Tmumat
            avgfert = sum(sum(sum(ngrid(nindmat_dist).*mumat0)));
            popgrowth = avgfert/2;
            Tmumatpre = Tmumatpre/avgfert;

            distance0 = max(max(abs(Tmumatpre-mumatpre0)));
            mumatpre0 = Tmumatpre;
            
            Tmusum = sum(Tmumatpre(:));

            sf = sprintf ( '     computing stationary dist: iter %4d    ||Tmumat-mumat0|| = %8.7f    sum(mu) = %8.5f    sum(Tmu) = %8.5f', iteration0, distance0, musum,Tmusum);
            disp(sf)
            
            iteration0 = iteration0 + 1;

        end
        % closing while loop for stationary distribution

        if (chi == 0) || (distoff == 1)
            distance =0;
        else
            distance = max(max(abs(mumatpre0-mumatpre)));
        end
        mumatpre = mumatpre0;

        % integrating out kappa to obtain marginal distribution of h
        muh = zeros(nh_dist,1);
        for ih_dist = 1:nh_dist
            muh(ih_dist) = sum(mumatpre(ih_dist,:));
        end

        % unconditional mean; updating distributional info
        Hmean = hgrid_dist*muh;

        % top 15 average
        cumh = cumsum(muh);
        topind = sum(cumh<pct_target) + 1;

        muhtop = muh(topind:nh_dist);
        hgridtop = hgrid_dist(topind:nh_dist);
        % adjustment
        muhtop(1) = muhtop(1) - (pct_target-cumh(topind-1));    
        H15 = hgridtop*muhtop/sum(muhtop);

        endIter = toc(startIter);
        
        iinner = sprintf ( '  expectation-consistent dist %2d    ||mumat-mumat0|| =%8.7f    Time(sec) =%6.2f    sum(mu) = %8.5f      1+g = %8.3f      H15 = %6.3f', iteration, distance, endIter, musum, popgrowth,H15);
        disp(iinner)

        iteration = iteration +1;
        if iteration > 20
            break
        end
    end

    % aggregate factor supply
    THs = 0;
    Ls = 0;
    xmean = 0;
    txmean = 0;
    Tnew = 0;

    for ih_dist = 1:nh_dist
        hpnow = hgrid_dist(ih_dist);
        for ik = 1:nk
            if mumatpre(ih_dist,ik) > 0
                for ib = 1:npsi
                    intemp = nindmat_dist(ih_dist,ib,ik);
                    % taking care of kappa
                    for jk = 1:nk
                        muval = prpsic(ib)*kappaprmat(ik,jk)*mumatpre(ih_dist,ik);

                        hwtemp = lini(hgrid,hwmat(:,ib,jk,intemp),hpnow);
                        xtemp = lini(hgrid,xmat(:,ib,jk,intemp),hpnow);

                        THs = THs + hwtemp*muval;
                        Ls = Ls + hpnow*hwtemp*muval;

                        if (w*hpnow*hwtemp<inccut)
                            Trntemp = Trn(omega,ngrid(intemp));
                        else
                            Trntemp = 0;
                        end

                        xmean = xmean + xtemp*muval;
                        txmean = txmean + ngrid(intemp)*xtemp*muval;
                        
                        Tnew = Tnew + ( taux*xtemp*ngrid(intemp) - Trntemp )*muval;
                    end
                end
            end
        end
    end

    Y = A*Ls;

    distanceout = max(abs(log(Ls)-log(L)),abs(T-Tnew));
    
    TY = T/Y;

    endIterout = toc(startIterout);
    disp('   ')
    s0f = sprintf ( 'outer loop %4d  (|pct(Ls-L)|) =%8.5f    Time elapsed =%8.2f'   , iterationout,distanceout, endIterout);
    s1f = sprintf ( '  L =%8.3f  Ls =%8.3f   taux =%8.3f  omega =%8.3f'   ,L,Ls,taux,omega);
    s4f = sprintf ( '  T =%8.3f  Tnew =%8.3f   T/Y =%8.5f'   ,T,Tnew,TY);
    s2f = sprintf ( '  Fertility rate =%8.3f   Total hours =%8.3f   mean(h) =%8.3f   mean(x) =%8.3f    Y =%8.3f'   ,avgfert,THs,Hmean,xmean,Y);

    s3f = sprintf ( '  '   );
    disp(s0f)
    disp(s1f)
    disp(s4f)
    disp(s2f)
    disp(s3f)

    % Updating
    L = Ls;

    % government budget balancing
    T = damph*T + (1-damph)*Tnew;

    iterationout = iterationout +1;

    if iterationout > 20
        break
    end
end


Minutes = toc(startsol);
sf = sprintf( '************* Total time of inner+outer loops (seconds) = %8.0f *************', Minutes);
disp(sf)


% Benchmark HK
if (distoff == 1)
    htilde = hbarhat;
else
    htilde = H15;
end

%%%%%%%%%%%%
%Simulation
simstart = tic;

s = RandStream('mt19937ar','Seed',1);
RandStream.setGlobalStream(s);

% random sampling from mu_initial
mu0dist = reshape(mumatpre,nh_dist*nk,1);
mu0name = linspace(1,nh_dist*nk,nh_dist*nk);
distind = randsample(s,mu0name,NS,true,mu0dist);
hdistsimind = zeros(NS,1);
kappasimind = zeros(NS,1);

for i = 1:NS
    hdistsimind(i,1) = rem(distind(i),nh_dist);
    if rem(distind(i),nh_dist) == 0
        hdistsimind(i,1) = nh_dist;
    end
    kappasimind(i,1) = fix((distind(i)-1)/nh_dist) + 1;
end

bname = linspace(1,npsi,npsi);
bsimind = randsample(s,bname,NS,true,prpsic);
bsimindkid = randsample(s,bname,NS,true,prpsic);

% kappakid random draw
kappaname = linspace(1,nk,nk);
kappasimindkid = zeros(NS,1);
kappasimindkidkid = zeros(NS,1);
for i = 1:NS
    kappasimindkid(i) = randsample(s,kappaname,1,true,kappaprmat(kappasimind(i),:));
end
for i = 1:NS
    kappasimindkidkid(i) = randsample(s,kappaname,1,true,kappaprmat(kappasimindkid(i),:));
end


% Simulating samples
nsim = zeros(NS,1);           % fertility
nsimpos = zeros(NS,1);        % fertility (with zero replaced with NaN)
child0 = zeros(NS,1);         % childlessness indicator

hwsim = zeros(NS,1);           % labor supply
consim = zeros(NS,1);
bsim = zeros(NS,1);

xsim = zeros(NS,1);           % parental investment
txsim = zeros(NS,1);          % per child parental money investment expenditure/income (for calibration)
nxsim = zeros(NS,1);          % total parental money investment expenditure (to check market clearing)

hsim = zeros(NS,2);           % parent's and children's human capital

incsim = zeros(NS,1);      % family income
incsim2 = zeros(NS,1);

transim = zeros(NS,1);

for i = 1:NS
    ih_dist = hdistsimind(i);
    ib = bsimind(i);
    ik = kappasimind(i);
    jk = kappasimindkid(i);

    nnow = ngrid(nindmat_dist(ih_dist,ib,ik));
    in = nindmat_dist(ih_dist,ib,ik);

    nsim(i,1) = nnow;
    nsimpos(i,1) = nnow;
    if nnow == 0
        child0(i,1) = 1;
        nsimpos(i,1) = NaN;
    end

    hsim(i,1) = hgrid_dist(ih_dist);
    hwsim(i,1) = lini(hgrid,hwmat(:,ib,jk,in),hsim(i,1));
    consim(i,1) = lini(hgrid,cmat(:,ib,jk,in),hsim(i,1));
    xsim(i,1) = lini(hgrid,xmat(:,ib,jk,in),hsim(i,1));
    nxsim(i,1) = ((1+taux)*xsim(i,1))*nsim(i,1);

    incsim(i,1) = w*hsim(i,1)*hwsim(i,1);
    bsim(i,1) = psicgrid(ib);

    txsim(i,1) = (xsim(i,1))/incsim(i,1);

    if (w*hsim(i,1)*hwsim(i,1) <inccut)
        Trntemp = Trn(omega,nnow);
    else
        Trntemp = 0;
    end

    transim(i,1) = T + Trntemp;

    hsim(i,2) = HKprodfn(Ah*kappagrid(jk),hsim(i,1),xsim(i,1),theta0,alpha1,alpha2);
    
    Vtemp = zeros(nn,1);
    jb = bsimindkid(i);
    jjk = kappasimindkidkid(i);
    for jn = 1:nn
        Vtemp(jn) = lini(hgrid,EVmat(:,jb,jk,jn),hsim(i,2));
    end
    [~, in2] = max(Vtemp);

    incsim2(i,1) = w*hsim(i,2)*lini(hgrid,hwmat(:,jb,jjk,in2),hsim(i,2));

end

budgetbalance = (sum(incsim)+sum(transim)-sum(nxsim)-sum(consim))/NS;
incmean = mean(incsim);
nxmean = mean(nxsim);
conmean = mean(consim);

s5f = sprintf ( '  Checking individual budget   Extra inc =%8.3f   Avg(income) =%8.3f   Avg(consum) =%8.3f   Avg(invest) =%8.3f   '   ,budgetbalance,incmean,conmean,nxmean);
disp(s5f)

avg_educinv_inc = sum(xsim(nsim>0))/sum(incsim(nsim>0));

avg_LS = mean(hwsim);

% elasticity consistent with empirical evidence
% obtain income quintile
incpct5 = quantile(incsim,4);

incquin = zeros(NS,1);
for ii = 1:NS
    if incsim(ii) < incpct5(1)
        incquin(ii) = 1;
    elseif (incsim(ii)>=incpct5(1))&&(incsim(ii)<incpct5(2))
        incquin(ii) = 2;
    elseif (incsim(ii)>=incpct5(2))&&(incsim(ii)<incpct5(3))
        incquin(ii) = 3;
    elseif (incsim(ii)>=incpct5(3))&&(incsim(ii)<incpct5(4))
        incquin(ii) = 4;
    else
        incquin(ii) = 5;
    end
end

AvgI5 = zeros(5,1);
AvgI5a = zeros(5,1);
AvgF5 = zeros(5,1);
AvgX5 = zeros(5,1);
AvgH5 = zeros(5,1);
pctN = zeros(5,1);
pctNpos = zeros(5,1);

for k = 1:5
    % income by income quintile
    AvgI5(k) = mean(incsim(incquin==k));
    % fertility by income quintile
    AvgF5(k) = mean(nsim(incquin==k));
    % per-child investmnet by income quintile
    AvgX5(k) = mean(xsim(incquin==k&nsim>0));
    AvgI5a(k) = mean(incsim(incquin==k&nsim>0));
    % labor supply by income quintile
    temp = mean(hsim(incquin==k));
    AvgH5(k) = temp(1);
    
    pctN(k) = sum(incquin==k);
    pctNpos(k) = sum(incquin==k&nsim>0);
end

Wmat = zeros(5,5);
for j = 1:5
    Wmat(j,j) = pctN(j);
end

elast0 = wls1(log(AvgF5),log(AvgI5),Wmat);
elastx = wls1(log(AvgX5),log(AvgI5),Wmat);

AvgN05 = pctNpos./pctN;
AvgN05 = 1 - AvgN05;

invinc5 = AvgX5./AvgI5a;

prn = zeros(nn,1);
prn(1) = sum((nsim==0))/NS;
prn(2) = sum((nsim==1))/NS;
prn(3) = sum((nsim==2))/NS;
prn(4) = sum((nsim==3))/NS;
prn(5) = sum((nsim==4))/NS;

Giniinc = ginicoeff(incsim);

hpvec = 0;
hkvec = 0;
ns = 0;
for ii = 1:NS
    if nsim(ii) > 0
        ns = ns + 1;
        hpvec(ns,1) = incsim(ii);
        hkvec(ns,1) = incsim2(ii);
    end
end

ige = ols1(log(hkvec(hpvec.*hkvec>0)),log(hpvec(hpvec.*hkvec>0)));

MinutesTotal = toc(simstart);
sf = sprintf( '************* Total time of simulation (seconds) = %8.0f ************  mu(nh) =%8.7f     mu(nh-20) =%8.7f', MinutesTotal,muh(nh_dist),muh(nh_dist-20));
disp(sf)


% Spillover effects in the model
% SR effects:
% use the stationary distribution; not searching for expectation-consistent distribution
% use the baseline fertility choices

% Step 1: Using "representative top x% agent", recover the necessary percentage change in htilde.
xmeandev = 0.9;   % 10% decrease = 0.9
xmean_p_chg = 100*(xmeandev-1);

p90val = prctile(hsim(:,1),pct_target*100);
xsimtemp = xsim;
xsimtemp(hsim(:,1)<p90val) = nan;
xsimtemp(nsim==0) = nan;

kappasimtemp = kappagrid(kappasimindkid);
kappasimtemp(hsim(:,1)<p90val) = nan;
kappasimtemp(nsim==0) = nan;

Hpmean0 = HKprodfn(Ah*mean(kappasimtemp,'omitnan'),H15,mean(xsimtemp,'omitnan'),theta0,alpha1,alpha2);
Hpmean1 = HKprodfn(Ah*mean(kappasimtemp,'omitnan'),H15,xmeandev*mean(xsimtemp,'omitnan'),theta0,alpha1,alpha2);

clear xsimtemp kappasimtemp

med_inc = median(incsim);

Hdev = Hpmean1/Hpmean0;

Vmat_iv = zeros(nh,npsi,nk,nn);
cmat_iv = zeros(nh,npsi,nk,nn);
lmat_iv = zeros(nh,npsi,nk,nn);
hwmat_iv = zeros(nh,npsi,nk,nn);
xmat_iv = zeros(nh,npsi,nk,nn);


        %%%%%%%%%%%%%%%%%%%%%%%%%%
        % Computing value functions and decision rules
        % Conditional on having no child (n=0)
        in = 1;
        nnow = ngrid(in);
        parfor ih = 1:nh
            hpnow = hgrid(ih);
            for ib = 1:npsi
                psic = psicgrid(ib);
                for ik = 1:nk
                    kappanow = kappagrid(ik);

                    lmax = 1;

                    if (w*hpnow*lmax > T)

                        nt0 = sum(tgrid<=lmax);
                        vvectemp = zeros(nt0,1);

                        objpos = @(les) ( psic*log(HES(w*hpnow*(lmax-les) + T,0)) + psil*((les)^(1-gamma))/(1-gamma) );

                        for it = 1:nt0
                            if isreal(objpos(tgrid(it)))==1
                                vvectemp(it) = objpos(tgrid(it));
                            else
                                vvectemp(it) = -inf;
                            end
                        end

                        [Nval, minind] = max(vvectemp);  % maximizing objective fn

                        lmat_iv(ih,ib,ik,in) = tgrid(minind);
                        hwmat_iv(ih,ib,ik,in) = lmax - tgrid(minind);
                        Vmat_iv(ih,ib,ik,in) = Nval;
                        cmat_iv(ih,ib,ik,in) = w*hpnow*hwmat_iv(ih,ib,ik,in) + T;

                        xmat_iv(ih,ib,ik,in) = 0;

                    else
                        % work full time but cannot afford positive consumption (due to lump-sum tax)
                        Vmat_iv(ih,ib,ik,in) = -inf;
                    end
                end
            end
        end



        parfor ih = 1:nh
            hpnow = hgrid(ih);
            for in = 2:nn
                nnow = ngrid(in);
                phinow = phigrid(in);
                for ib = 1:npsi
                    psic = psicgrid(ib);
                    for ik = 1:nk
                        kappanow = kappagrid(ik);

                        if (distoff==1)
                            htilde = Hdev*hbarhat;
                        else
                            htilde = Hdev*H15;
                        end

                        % Conditional on having positive no. of children (n>0)

                        lmax = 1 - lambda*nnow;

                        nt0 = sum(tgrid<=lmax);

                        if (qualutil10(HKprodfn(Ah*kappanow,hpnow,0,theta0,alpha1,alpha2),htilde,chi,sigma)>-inf)
                            xmin = 0;
                        else
                            xmin = max( (((chi*htilde)/(Ah*kappanow) - theta0)^(1/alpha1))*(hpnow^(-alpha2/alpha1)), 0);
                        end

                        % case 1: interior x > xmin
                        vvectemp1 = zeros(nt0,1);
                        cvectemp1 = zeros(nt0,1);

                        for it = 1:nt0
                            if (w*hpnow*(lmax-tgrid(it))<inccut)
                                Trntemp = Trn(omega,nnow);
                            else
                                Trntemp = 0;
                            end

                            cmax = w*hpnow*(lmax-tgrid(it)) + T + Trntemp - (1+taux)*xmin*nnow;

                            if (cmax <= 0)
                                vvectemp1(it) = -inf;
                            else
                                % v12d
                                objneg1 = @(c) - ( psic*log(HES(c, nnow)) + psil*(tgrid(it)^(1-gamma))/(1-gamma) ...
                                    + phinow*qualutil10(HKprodfn(Ah*kappanow,hpnow,(w*hpnow*(lmax-tgrid(it)) + T + Trntemp - c )/((1+taux)*nnow),theta0,alpha1,alpha2),htilde,chi,sigma) );

                                cvectemp1(it) = GSS(objneg1,0,cmax,tol);
                                vvectemp1(it) = -objneg1(cvectemp1(it));
                            end
                        end

                        [Vval1, maxind1] = max(vvectemp1);  % maximizing over values

                        % case 2: x = xmin
                        vvectemp2 = zeros(nt0,1);


                        for it = 1:nt0
                            if (w*hpnow*(lmax-tgrid(it))<inccut)
                                Trntemp = Trn(omega,nnow);
                            else
                                Trntemp = 0;
                            end

                            cmax = w*hpnow*(lmax-tgrid(it)) + T + Trntemp - (1+taux)*xmin*nnow;

                            objpos2 = @(les) ( psic*log(HES(w*hpnow*(lmax-les) + T + Trntemp - (1+taux)*xmin*nnow,nnow)- (1+taux)*xmin*nnow) + psil*((les)^(1-gamma))/(1-gamma) ...
                                + phinow*qualutil10(HKprodfn(Ah*kappanow,hpnow,xmin,theta0,alpha1,alpha2),htilde,chi,sigma) );

                            if (cmax <= 0)
                                vvectemp2(it) = -inf;
                            else
                                vvectemp2(it) = objpos2(tgrid(it));
                            end
                        end

                        [Vval2, maxind2] = max(vvectemp2);  % maximizing objective fn

                        if (Vval1>Vval2)
                            lmat_iv(ih,ib,ik,in) = tgrid(maxind1);
                            hwmat_iv(ih,ib,ik,in) = lmax - tgrid(maxind1);
                            if (w*hpnow*(lmax-tgrid(maxind1))<inccut)
                                Trntemp = Trn(omega,nnow);
                            else
                                Trntemp = 0;
                            end
                            xmat_iv(ih,ib,ik,in) = (w*hpnow*(lmax-tgrid(maxind1)) + T + Trntemp - cvectemp1(maxind1) )/((1+taux)*nnow);
                            cmat_iv(ih,ib,ik,in) = cvectemp1(maxind1);
                            Vmat_iv(ih,ib,ik,in) = Vval1;
                        else
                            lmat_iv(ih,ib,ik,in) = tgrid(maxind2);
                            hwmat_iv(ih,ib,ik,in) = lmax - tgrid(maxind2);
                            if (w*hpnow*(lmax-tgrid(maxind2))<inccut)
                                Trntemp = Trn(omega,nnow);
                            else
                                Trntemp = 0;
                            end
                            xmat_iv(ih,ib,ik,in) = xmin;
                            cmat_iv(ih,ib,ik,in) = w*hpnow*(lmax-tgrid(maxind2)) + T + Trntemp - (1+taux)*xmin*nnow;
                            Vmat_iv(ih,ib,ik,in) = Vval2;
                        end

                    end
                end
            end
        end

        % expectation w.r.t. productivity
        EVtemp = zeros(nh,npsi,nk,nn);
        for ih = 1:nh
            for ib = 1:npsi
                for in = 1:nn
                    for ik = 1:nk
                        EVtempval = 0;
                        for jk = 1:nk
                            EVtempval = EVtempval + kappaprmat(ik,jk)*Vmat_iv(ih,ib,jk,in);
                        end
                        EVtemp(ih,ib,ik,in) = EVtempval;
                    end
                end
            end
        end

        EVmat_iv = EVtemp;

        nindmat_iv_dist = zeros(nh_dist,npsi,nk);

        % Fertility decision on finer grids
            parfor ih_dist = 1:nh_dist
                hpnow = hgrid_dist(ih_dist);
                for ik = 1:nk
                    for ib = 1:npsi
                        % 1. fertility
                        % obtain conditional values on hgrid_dist
                        valvectemp = zeros(nn,1);
                        for in = 1:nn
                            valvectemp(in,1) = lini(hgrid,EVmat_iv(:,ib,ik,in),hpnow);
                        end
                        % find maximum index for n choice
                        [~ , maxindn] = max(valvectemp);
                        nindmat_iv_dist(ih_dist,ib,ik) = maxindn;

                    end
                end
            end






%%%%%%%%%%%%
%Simulation
% Key objects: xsim + consim
xsim_iv = zeros(NS,1);
consim_iv = zeros(NS,1);
incsim_iv = zeros(NS,1);
nsim_iv = zeros(NS,1);
xratiosim = zeros(NS,1);
xratiosim_iv = zeros(NS,1);


for i = 1:NS
    ih_dist = hdistsimind(i);
    ib = bsimind(i);
    ik = kappasimind(i);
    jk = kappasimindkid(i);

    % using baseline fertility
    in = nindmat_iv_dist(ih_dist,ib,ik);

    nsim_iv(i) = in-1;

    hpnow = hgrid_dist(ih_dist);
    consim_iv(i,1) = lini(hgrid,cmat_iv(:,ib,jk,in),hpnow);
    xsim_iv(i,1) = lini(hgrid,xmat_iv(:,ib,jk,in),hpnow);

    xratiosim(i) = (((1+taux)*xsim(i,1)))/((((1+taux)*xsim(i,1))*nsim(i))+consim(i));
    xratiosim_iv(i) = (((1+taux)*xsim_iv(i,1)))/((((1+taux)*xsim_iv(i,1))*nsim_iv(i))+consim_iv(i));

    incsim_iv(i) = w*hpnow*lini(hgrid,hwmat_iv(:,ib,jk,in),hpnow);

end

xratio_pp_chg = 100*(mean(xratiosim_iv(nsim>0&incsim<med_inc)) - mean(xratiosim(nsim>0&incsim<med_inc)));
iv_coeff = xratio_pp_chg/xmean_p_chg;

% remove unnecessary info to save space
clear lmat_iv hwmat_iv xmat_iv cmat_iv xsim_iv consim_iv nsim_iv hsim_iv incsim_iv

objval = ((0.053-AvgN05(1))/0.053)^2 + ((0.196-prn(2))/0.196 )^2 + ((0.631-prn(3))/0.631 )^2 + ((0.144-prn(4))/0.144 )^2 + ...
    ((0.039-iv_coeff)/ 0.039 )^2 + ((avg_educinv_inc-0.092)/0.092 )^2 + ((elast0-0.082)/0.082 )^2 + ...
    ((0.301-avg_LS)/ 0.301 )^2 + ((0.263-Giniinc)/ 0.263 )^2 + ((0.698-elastx)/0.698 )^2 + ((ige-0.32)/0.32 )^2 + ((Y-Yss)/Yss )^2;

title = sprintf( '______________________________ End of Solving the Steady State Equilibrium ______________________________ ');
disp(title)


if (option==6)
    % For Table A11
    fname = ['meanstested','.txt'];
    stat1=avgfert;
    stat2=100*prn(1);
    stat3=100*avg_educinv_inc;
    stat4=elast0;
    stat5=elastx;
    stat6=avg_LS;
    stat7=Hmean;
    stat8=Y;
    stat9=Giniinc;
    stat10=ige;
    stat11=100*abs(TY);

    save(fname,'stat1','stat2','stat3','stat4','stat5','stat6','stat7','stat8','stat9','stat10','stat11','-ascii')   
end








