%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% "Status Externalities in Education and Low Birth Rates in Korea"
% Seongeun Kim, Michele Tertilt, and Minchul Yum

% Status Externality Model (Benchmark)
% Replication commands
% note: running the code sequentially ensure that all results are replicated
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;

% Parameters externally calibrated
gamma = 2.0;
lambda = 0.057*18/25;   % per kid parental time = 5.7 hrs per week

% Parameters internally calibrated
chi = 0.078211519;      
theta0 = 1.0787131;
Ah = 2.2254829;         
psil = 1.8678885;   
psicsd = 0.5865557;
phi1 = 1.3913291;
phi2add = 0.78402234;
phi3add = 0.39724406;
kappasd = 0.36132727;
alpha1 =  0.66838201;   
kapparho = 0.37556873;

% policy parameters
taux= 0.0;
omega = 0.0;
eta = 0.0;





% 1. solve baseline steady-state and display Table 4 and Table 5; and save steady state results for transition equilibrium
Prog_MainSS(1,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,taux,omega,0);

% 2. solve the model with chi=0 and display Figure 3 and Table 6
Prog_MainSS(2,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,0.0,taux,omega,0);

% 3. solve the model when average cost of rasing a child (time cost) is reduced by 4.34% and display Table 7
Prog_MainSS(3,Ah,psicsd,psil,lambda*(1-0.0434),phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,taux,omega,0)

% 4. solve the model with policies and display Table 8
% Pro-natal transfers
Prog_MainSS(4,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,taux,0.01,0);
Prog_MainSS(4,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,taux,0.02,0);
% Education tax
Prog_MainSS(4,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,0.1,omega,0);
Prog_MainSS(4,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,0.2,omega,0);



% 5. solve for the optimal policy numerically (Section 7.2) and display optimal policy
negishi = 1; perm = 1;
objfn = @(x) Prog_MainTR(0,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,x(1),x(2),negishi,perm,0);

x0(1) = log(0.30); x0(2) = log(0.01);
 
minparvec = fminsearch(objfn,x0,optimset('TolX',1e-6,'TolFun',1e-6,'Display','iter','FunValCheck','on','MaxFunEvals',1000,'MaxIter',1000));
mom1 = sprintf( 'Optimal policy: taux=%6.3f   phi=%7.4f  ',exp(minparvec(1)),exp(minparvec(2)));
disp(mom1)

% 6. obtain steady state with optimal permanent policy with Negishi weights and display Table 9 and Figure 5
negishi = 1;
perm = 1;
Prog_MainTR(1,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,log(0.215533877320545),log(0.017526368076404),negishi,perm,0);

% 7. solve the model and obtain Table A10
Prog_MainSS(5,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,taux,omega,0);
Prog_MainSS(5,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,taux,0.02,0);
Prog_MainSS(5,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,taux,0.02,1);
Prog_MainSS(5,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,0.2,omega,0);
Prog_MainSS(5,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,0.2,omega,1);
GenTableA10;

% 8. solve the model and obtain Table A11
Prog_MainSS(6,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,taux,omega,0);
Prog_MainSS(6,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,taux,0.02,0);
Prog_MainSS_A11(6,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,taux,0.0266,0);
GenTableA11;

% 9. obtain steady state with different policy with Negishi weights and generate Figure A7
negishi = 1;
perm = 1;
Prog_MainTR_App(0,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,log(0.0),log(0.02),negishi,perm,0);

% 10. obtain steady state with different policy with Negishi weights and generate Figure A8
negishi = 1;
perm = 1;
Prog_MainTR_App(0,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,log(0.2),log(0.0),negishi,perm,0);

% 11. compute transition equillibrium with different policies and draw Figures A9
num = 20;
tauxvectemp = linspace(0,0.4,num+1);
tauxvec = tauxvectemp(1,2:num+1)';
omegavectemp = linspace(0,0.04,num+1);
omegavec = omegavectemp(1,2:num+1)';

negishi = 1; perm = 1;
Prog_MainTR_App(3,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,log(0.0),log(0.0),negishi,perm,0);
for i = 1:num    
    taux1 = log(tauxvec(i,1));
    Prog_MainTR_App(3,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,taux1,log(0.0),negishi,perm,0);
    Prog_MainTR_App(3,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,taux1,log(0.0),negishi,perm,1);    
end
for i = 1:num    
    omega1 = log(omegavec(i,1));
    Prog_MainTR_App(3,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,log(0.0),omega1,negishi,perm,0);
    Prog_MainTR_App(3,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,log(0.0),omega1,negishi,perm,1);
end
GenFigureA9;

% 12. Optimal temporary policy with Negishi weights and display Figure A10
negishi = 1;
perm = 0;
Prog_MainTR(2,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,log(0.215929221951967),log(0.01783823),negishi,perm,0);

% 13. Optimal permanent policy with equal weights and display Figure A11 and Table A12
negishi = 0;
perm = 1;
Prog_MainTR(3,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,log(0.39671563),log(0.000000025496198),negishi,perm,0);
Prog_MainTR(4,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,log(0.16670473),log(0.00000040311794),negishi,perm,1);
GenFigureA11;

% 14. Optimal temporary policy with equal weights and display Figure A12
negishi = 0;
perm = 0;
Prog_MainTR(3,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,log(0.3984272),log(1.4531169e-08),negishi,perm,0);
Prog_MainTR(4,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,log(0.16140078),log(4.4896e-06),negishi,perm,1);
GenFigureA12;

% 15. Figures A13
num = 20;
tauxvectemp = linspace(0,0.4,num+1);
tauxvec = tauxvectemp(1,2:num+1)';
omegavectemp = linspace(0,0.04,num+1);
omegavec = omegavectemp(1,2:num+1)';

negishi = 0; perm = 1;
Prog_MainTR_App(3,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,log(0.0),log(0.0),negishi,perm,0);
for i = 1:num    
    taux1 = log(tauxvec(i,1));
    Prog_MainTR_App(3,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,taux1,log(0.0),negishi,perm,0);
    Prog_MainTR_App(3,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,taux1,log(0.0),negishi,perm,1);    
end
for i = 1:num    
    omega1 = log(omegavec(i,1));
    Prog_MainTR_App(3,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,log(0.0),omega1,negishi,perm,0);
    Prog_MainTR_App(3,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,gamma,kapparho,kappasd,alpha1,theta0,chi,log(0.0),omega1,negishi,perm,1);
end
GenFigureA13;

