function objval = Prog_TourTR(option,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,base,gamma,kapparho,kappasd,alpha1,theta0,chi,scale,taux,omega,negishi,perm,distoff)
% Combining steady-state (first half) + transition (second half)

% % Transformation
taux = exp(taux);
omega = exp(omega);

nh = 36;       % HK grid for value, decision
nh_dist = 500;      % HK grid for distribution
hhigh0 = 15;

% For shutting down externality
hbarhat = 5.783218901406690;
pct_target = 0.85;     % 0.9 = top 10%

if (perm==1)
disp0 = sprintf( '______________________________ Computing Steady State Equilibrium (end point) ______________________________ ');
disp(disp0)

A = 1.0;
Yss = 1.0;
alpha2 = 0;   % not used
psicmean = 1;

% meta parameters
tol = 1e-4;
toldist = 1e-6;
tolout = 1e-4;
damph = 0.0;   % dampening parameter   

nn = 4;      % maximum number of children - 1
nk = 20;     % number of grid for kappa 
npsi = 20;   % number of grid for psi
nt = 50;     % number of grid for time; chosen to be large enough to get stable results

ngrid = linspace(0,nn-1,nn);     % grid for number of children 0,1,...

% custermized grid
tgrid = zeros(1,nt);
nt0 = round(nt*0.9);
tgrid(1,1:nt0) = linspace(tol,0.7,nt0);
tgrid(1,nt0:nt) = linspace(0.7,1,nt-nt0+1);

% log normal distribution
[kappagrid, kappaprmat] = tauchen(0,kappasd,kapparho,3,nk);
kappagrid = exp(kappagrid);    

[psicgrid, prpsic] = tauchen(0,psicsd,0,3,npsi);
psicgrid = exp(psicgrid)*psicmean;
prpsic = prpsic(1,:);

% non-parametric utility along quantity
phigrid = zeros(nn,1);
phigrid(2) = phi1;
phigrid(3) = phi1+phi2add;
phigrid(4) = phi1+phi2add+phi3add;

hlow = max(0.1,HKprodfn(Ah*kappagrid(1),0,0,theta0,alpha1,alpha2));   

hhigh = Yss*hhigh0;    
hgrid = gengrid(hlow,hhigh,nh,2,2.0);
hgrid_dist = linspace(hlow,hhigh,nh_dist);

NS = 500000;   % number of simulated samples

% initialization
Vmat = zeros(nh,npsi,nk,nn);
cmat = zeros(nh,npsi,nk,nn);
lmat = zeros(nh,npsi,nk,nn);
hwmat = zeros(nh,npsi,nk,nn);
xmat = zeros(nh,npsi,nk,nn);

nindmat = zeros(nh,npsi,nk);
nmat = zeros(nh,npsi,nk);

nindmat_dist = zeros(nh_dist,npsi,nk);

% initial guess for L
L = Yss;

% Outer loop: find equilibrium prices
startsol = tic;

iterationout = 1; distanceout = 10000;

T = 0;

% initial guess
Hmean = L*3;
H15 = L*5.5;

% initial distribution
mumatpre = ones(nh_dist,nk)/(nh_dist*nk);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%           OUTER LOOP            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

while distanceout > tolout
    startIterout = tic;    
    w = A;
    
    i0 = sprintf ( 'H15 =%8.2f     Hmean = %8.2f     hhigh = %8.2f    hlow = %8.2f', H15, Hmean, hhigh, hlow);    
    disp(i0)

           
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%           INNER LOOP            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Find the expectation-consistent distribution    
    
    iteration = 1; distance = 10000;
    
    while distance > toldist
        startIter = tic;
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%
        % Computing value functions and decision rules 
        % Conditional on having no child (n=0)   
        in = 1;
        nnow = ngrid(in);
        parfor ih = 1:nh        
            hpnow = hgrid(ih);                
            for ib = 1:npsi
                psic = psicgrid(ib);
                for jk = 1:nk
                    kappanow = kappagrid(jk);

                    lmax = 1;

                    if (w*hpnow*lmax > T + Trn(omega,nnow))
                        
                        nt0 = sum(tgrid<=lmax);
                        
                        objpos = @(les) ( psic*log(HES(w*hpnow*(lmax-les) + T + Trn(omega,nnow),0)) + psil*((les)^(1-gamma))/(1-gamma) );

                        vvectemp = zeros(nt0,1);
                        for it = 1:nt0
                            if isreal(objpos(tgrid(it)))==1
                                vvectemp(it) = objpos(tgrid(it));
                            else
                                vvectemp(it) = -inf;
                            end
                        end
    
                        [Nval, minind] = max(vvectemp);  % maximizing objective fn
                        
                        lmat(ih,ib,jk,in) = tgrid(minind);
                        hwmat(ih,ib,jk,in) = lmax - tgrid(minind);
                        Vmat(ih,ib,jk,in) = Nval;
                        cmat(ih,ib,jk,in) = w*hpnow*hwmat(ih,ib,jk,in) + T + Trn(omega,nnow);
                        
                        xmat(ih,ib,jk,in) = 0;

                    else
                        % work full time but cannot afford positive consumption (due to lump-sum tax)     
                        Vmat(ih,ib,jk,in) = -inf;
                    end
                    
                end
            end            
        end

        

        parfor ih = 1:nh        
            hpnow = hgrid(ih);
            for in = 2:nn
                nnow = ngrid(in);                
                phinow = phigrid(in);
                for ib = 1:npsi
                    psic = psicgrid(ib);
                    for jk = 1:nk
                        kappanow = kappagrid(jk);
                        
                        if (distoff==1) 
                            htilde = hbarhat;
                        else
                            %htilde = Hmean;
                            htilde = H15;
                        end    

                        % Conditional on having positive no. of children (n>0)

                        lmax = 1 - lambda*nnow;   

                        nt0 = sum(tgrid<=lmax);
                        
                        xmin = 0;

                        % case 1: interior x > xmin
                        vvectemp1 = zeros(nt0,1);
                        cvectemp1 = zeros(nt0,1);

                        for it = 1:nt0
                            cmax = w*hpnow*(lmax-tgrid(it)) + T + Trn(omega,nnow) - (1+taux)*xmin*nnow;

                            if (cmax <= 0)
                                vvectemp1(it) = -inf;
                            else
                                objneg1 = @(c) - ( psic*log(HES(c, nnow)) + psil*(tgrid(it)^(1-gamma))/(1-gamma) ...
                                    + phinow*qualutil10t(HKprodfn(Ah*kappanow,hpnow,(w*hpnow*(lmax-tgrid(it)) + T + Trn(omega,nnow) - c )/((1+taux)*nnow),theta0,alpha1,alpha2),htilde,chi,scale,base) );
                            
                                cvectemp1(it) = GSS(objneg1,0,cmax,tol);
                                vvectemp1(it) = -objneg1(cvectemp1(it));
                            end
                        end

                        [Vval1, maxind1] = max(vvectemp1);  % maximizing over values

                        % case 2: x = xmin
                        vvectemp2 = zeros(nt0,1);
                        
                        objpos2 = @(les) ( psic*log(HES(w*hpnow*(lmax-les) + T + Trn(omega,nnow)- (1+taux)*xmin*nnow,nnow)) + psil*((les)^(1-gamma))/(1-gamma) ...
                            + phinow*qualutil10t(HKprodfn(Ah*kappanow,hpnow,xmin,theta0,alpha1,alpha2),htilde,chi,scale,base) );

                        for it = 1:nt0
                            cmax = w*hpnow*(lmax-tgrid(it)) + T + Trn(omega,nnow) - (1+taux)*xmin*nnow;

                            if (cmax <= 0)
                                vvectemp2(it) = -inf;
                            else
                                vvectemp2(it) = objpos2(tgrid(it));
                            end
                        end

                        [Vval2, maxind2] = max(vvectemp2);  % maximizing objective fn

                        if (isreal(Vval1)==0) && (isreal(Vval2)==0)
                            lmat(ih,ib,jk,in) = 0;
                            hwmat(ih,ib,jk,in) = 0;
                            xmat(ih,ib,jk,in) = 0;
                            cmat(ih,ib,jk,in) = 0;
                            Vmat(ih,ib,jk,in) = -inf;

                        elseif (Vval1>Vval2) 
                            lmat(ih,ib,jk,in) = tgrid(maxind1);   
                            hwmat(ih,ib,jk,in) = lmax - tgrid(maxind1);
                            xmat(ih,ib,jk,in) = (w*hpnow*(lmax-tgrid(maxind1)) + T + Trn(omega,nnow) - cvectemp1(maxind1) )/((1+taux)*nnow);
                            cmat(ih,ib,jk,in) = cvectemp1(maxind1);
                            Vmat(ih,ib,jk,in) = Vval1;
                        else
                            lmat(ih,ib,jk,in) = tgrid(maxind2);   
                            hwmat(ih,ib,jk,in) = lmax - tgrid(maxind2);
                            xmat(ih,ib,jk,in) = xmin;
                            cmat(ih,ib,jk,in) = w*hpnow*(lmax-tgrid(maxind2)) + T + Trn(omega,nnow)- (1+taux)*xmin*nnow;
                            Vmat(ih,ib,jk,in) = Vval2;
                        end
                        
                    end
                end
            end
        end

        % Obtain expected utility
        % expectation w.r.t. productivity         
        EVtemp = zeros(nh,npsi,nk,nn);
        for ih = 1:nh
            for ib = 1:npsi                
                for in = 1:nn
                    for ik = 1:nk
                        EVtempval = 0;
                        for jk = 1:nk
                            EVtempval = EVtempval + kappaprmat(ik,jk)*Vmat(ih,ib,jk,in);
                        end
                        EVtemp(ih,ib,ik,in) = EVtempval;
                    end
                end
            end            
        end
        
        EVmat = EVtemp;
                
        % Fertility decision   
        for ih = 1:nh
            for ib = 1:npsi  
                for ik = 1:nk
                    [~, nindmat(ih,ib,ik)] = max(EVmat(ih,ib,ik,:));
                    nmat(ih,ib,ik) = ngrid(nindmat(ih,ib,ik));                
                end
            end            
        end
        
        if (sum(nmat)==0)
            disp(' !! Warning: nobody wants to have kids !!')
        end
                        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % stationary distribution            
        
        % conditional on being able to have kid + ability draw
        jhmat = zeros(nh_dist,npsi,nk,nk);
        whmat = zeros(nh_dist,npsi,nk,nk);
        
        mumatpre0 = mumatpre;

        iteration0 = 1;   distance0 = 10000;
        while distance0 > toldist            
            Tmumatpre = zeros(nh_dist,nk);
            
            parfor ih_dist = 1:nh_dist     
                hpnow = hgrid_dist(ih_dist); 
                for ik = 1:nk                            
                    for ib = 1:npsi                            
                        % 1. fertility
                        % obtain conditional values on hgrid_dist
                        valvectemp = zeros(nn,1);
                        for in = 1:nn
                            valvectemp(in,1) = lini(hgrid,EVmat(:,ib,ik,in),hpnow);                            
                        end
                        % find maximum index for n choice
                        [~ , maxindn] = max(valvectemp);
                        nindmat_dist(ih_dist,ib,ik) = maxindn;                        
                        
                        for jk = 1:nk
                            kappakid = kappagrid(jk); 
                            % 2. private education spending
                            xtemp = lini(hgrid,xmat(:,ib,jk,maxindn),hpnow);

                            % 3. then find implied h'
                            hnexttemp = HKprodfn(Ah*kappakid,hpnow,xtemp,theta0,alpha1,alpha2);

                            % finding indices and weights
                            if hnexttemp <= hgrid_dist(1)
                                jhmat(ih_dist,ib,ik,jk) = 1;
                                whmat(ih_dist,ib,ik,jk) = 1;
                                
                            elseif hnexttemp >= hgrid_dist(nh_dist)
                                jhmat(ih_dist,ib,ik,jk) = nh_dist - 1;
                                whmat(ih_dist,ib,ik,jk) = 0;
                                
                            else
                                jhmat(ih_dist,ib,ik,jk) = sum(hgrid_dist<hnexttemp);
                                whmat(ih_dist,ib,ik,jk) = (hgrid_dist(jhmat(ih_dist,ib,ik,jk)+1) - hnexttemp)/(hgrid_dist(jhmat(ih_dist,ib,ik,jk)+1) - hgrid_dist(jhmat(ih_dist,ib,ik,jk)));

                            end

                        end
                    end                    
                end
            end
            
            
            for ih_dist = 1:nh_dist
                for ik = 1:nk
                    if mumatpre0(ih_dist,ik) > 0
                        for ib = 1:npsi                
                            muval = mumatpre0(ih_dist,ik)*prpsic(ib);
                            % shocks realized
                            for jk = 1:nk
                                jh = jhmat(ih_dist,ib,ik,jk);
                                wgt_hnext = whmat(ih_dist,ib,ik,jk);
                                Tmumatpre(jh,jk) = Tmumatpre(jh,jk) + kappaprmat(ik,jk)*wgt_hnext*ngrid(nindmat_dist(ih_dist,ib,ik))*muval;
                                Tmumatpre(jh+1,jk) = Tmumatpre(jh+1,jk) + kappaprmat(ik,jk)*(1-wgt_hnext)*ngrid(nindmat_dist(ih_dist,ib,ik))*muval;                                
                            end
                        end                        
                    end
                end            
            end
            
            musum = sum(mumatpre0(:));

            mumat0 = zeros(nh_dist,npsi,nk);
            for ih_dist = 1:nh_dist
                for ik = 1:nk
                    for ib = 1:npsi
                        mumat0(ih_dist,ib,ik) = prpsic(ib)*mumatpre0(ih_dist,ik);
                    end
                end
            end

            % scaling Tmumat
            avgfert = sum(sum(sum(ngrid(nindmat_dist).*mumat0)));
            popgrowth = avgfert/2;
            Tmumatpre = Tmumatpre/avgfert;

            distance0 = max(max(abs(Tmumatpre-mumatpre0)));
            mumatpre0 = Tmumatpre;
            
            Tmusum = sum(Tmumatpre(:));

            sf = sprintf ( '           computing stationary dist: iter %4d    ||Tmumat-mumat0|| = %8.7f    sum(mu) = %8.5f    sum(Tmu) = %8.5f', iteration0, distance0, musum,Tmusum);
            disp(sf)
              
            iteration0 = iteration0 + 1;

        end   
        % closing while loop for stationary distribution
                
        if (chi == 0) || (distoff == 1)
            distance =0;
        else
            distance = max(max(abs(mumatpre0-mumatpre)));
        end
        mumatpre = mumatpre0;
        
        % integrating out kappa to obtain marginal distribution of h
        muh = zeros(nh_dist,1);
        for ih_dist = 1:nh_dist
            muh(ih_dist) = sum(mumatpre(ih_dist,:));
        end        
        
        % unconditional mean; updating distributional info
        Hmean = hgrid_dist*muh;

        % top 15 average        
        cumh = cumsum(muh);
        topind = sum(cumh<pct_target) + 1;  

        %H15 = hgrid(p90ind:nh)*muh(p90ind:nh)/sum(muh(p90ind:nh));

        muhtop = muh(topind:nh_dist);
        hgridtop = hgrid_dist(topind:nh_dist);
        % adjustment
        muhtop(1) = muhtop(1) - (pct_target-cumh(topind-1));
        H15 = hgridtop*muhtop/sum(muhtop);

        endIter = toc(startIter);
            
        iinner = sprintf ( '  expec-cons dist %2d    ||mumat-mumat0|| =%8.7f    Time(sec) =%6.2f    sum(mu) = %8.5f      1+g = %8.3f      H15 = %6.3f', iteration, distance, endIter, musum, popgrowth,H15);
        disp(iinner)            
       

        iteration = iteration +1; 
        if iteration > 20
            break
        end        
    end
    
    % aggregate factor supply    
    THs = 0;
    Ls = 0;
    xmean = 0;
    txmean = 0;
    Tnew = 0;
    
    for ih_dist = 1:nh_dist  
        hpnow = hgrid_dist(ih_dist);
        for ik = 1:nk                
            if mumatpre(ih_dist,ik) > 0
                for ib = 1:npsi
                    intemp = nindmat_dist(ih_dist,ib,ik);
                    % taking care of kappa
                    for jk = 1:nk
                        muval = prpsic(ib)*kappaprmat(ik,jk)*mumatpre(ih_dist,ik);

                        hwtemp = lini(hgrid,hwmat(:,ib,jk,intemp),hpnow);
                        xtemp = lini(hgrid,xmat(:,ib,jk,intemp),hpnow);

                        THs = THs + hwtemp*muval;
                        Ls = Ls + hpnow*hwtemp*muval;
                        xmean = xmean + xtemp*muval;    
                        txmean = txmean + ngrid(intemp)*xtemp*muval;                           
                        Tnew = Tnew + ( taux*xtemp*ngrid(intemp) - (Trn(omega,ngrid(intemp))) )*muval;                    
                    end
                end  
            end
        end        
    end
    
    Y = A*Ls;
        
    distanceout = max(abs(log(Ls)-log(L)),abs(T-Tnew));
        
    TY = T/Y;
    
    endIterout = toc(startIterout);
    disp('   ')
    s0f = sprintf ( 'outer loop %4d  (|pct(Ls-L)|) =%8.5f    Time elapsed =%8.2f'   , iterationout,distanceout, endIterout);
    s1f = sprintf ( '  L =%8.3f  Ls =%8.3f   taux =%8.3f  psi =%8.3f'   ,L,Ls,taux,omega);
    s4f = sprintf ( '  T =%8.3f  Tnew =%8.3f   T/Y =%8.5f'   ,T,Tnew,TY);
    s2f = sprintf ( '  Fertility rate =%8.3f   Total hours =%8.3f   mean(h) =%8.3f   mean(x) =%8.3f    Y =%8.3f'   ,avgfert,THs,Hmean,xmean,Y);
        
    s3f = sprintf ( '  '   );
    disp(s0f)
    disp(s1f)
    disp(s4f)
    disp(s2f)
    disp(s3f)        
    
    % Updating
    L = Ls;

    % government budget balancing  
    T = damph*T + (1-damph)*Tnew;
    
    iterationout = iterationout +1;
    
    if iterationout > 20
        break
    end
end


Minutes = toc(startsol);
sf = sprintf( '****************** Total time of inner+outer loops (seconds) = %8.0f ******************', Minutes);
disp(sf)


% Benchmark HK
if (distoff == 1)
    htilde = hbarhat;
else
    htilde = H15;
end

%%%%%%%%%%%%
%Simulation
simstart = tic;

s = RandStream('mt19937ar','Seed',2);
RandStream.setGlobalStream(s);

% random sampling from mu_initial
mu0dist = reshape(mumatpre,nh_dist*nk,1);
mu0name = linspace(1,nh_dist*nk,nh_dist*nk);
distind = randsample(s,mu0name,NS,true,mu0dist);
hdistsimind = zeros(NS,1);
kappasimind = zeros(NS,1);

for i = 1:NS    
    hdistsimind(i,1) = rem(distind(i),nh_dist);
    if rem(distind(i),nh_dist) == 0
        hdistsimind(i,1) = nh_dist;
    end
    kappasimind(i,1) = fix((distind(i)-1)/nh_dist) + 1;
end

bname = linspace(1,npsi,npsi);
bsimind = randsample(s,bname,NS,true,prpsic);
bsimindkid = randsample(s,bname,NS,true,prpsic);

% kappakid random draw
kappaname = linspace(1,nk,nk);
kappasimindkid = zeros(NS,1);
kappasimindkidkid = zeros(NS,1);
for i = 1:NS
    kappasimindkid(i) = randsample(s,kappaname,1,true,kappaprmat(kappasimind(i),:));
end
for i = 1:NS
    kappasimindkidkid(i) = randsample(s,kappaname,1,true,kappaprmat(kappasimindkid(i),:));
end


% Simulating samples
nsim = zeros(NS,1);           % fertility
nsimpos = zeros(NS,1);        % fertility (with zero replaced with NaN)
child0 = zeros(NS,1);         % childlessness indicator

hwsim = zeros(NS,1);           % labor supply 
leisuresim = zeros(NS,1);           % labor supply 
consim = zeros(NS,1);
bsim = zeros(NS,1);

xsim = zeros(NS,1);           % parental investment
txsim = zeros(NS,1);          % per child parental money investment expenditure/income (for calibration)
nxsim = zeros(NS,1);          % total parental money investment expenditure (to check market clearing)

hsim = zeros(NS,2);           % parent's and children's human capital

incsim = zeros(NS,1);      % family income
incsim2 = zeros(NS,1);

transim = zeros(NS,1);

for i = 1:NS
    ih_dist = hdistsimind(i);
    ib = bsimind(i);
    ik = kappasimind(i);  
    jk = kappasimindkid(i);

    nnow = ngrid(nindmat_dist(ih_dist,ib,ik));
    in = nindmat_dist(ih_dist,ib,ik);
    
    nsim(i,1) = nnow;
    nsimpos(i,1) = nnow;
    if nnow == 0
        child0(i,1) = 1;
        nsimpos(i,1) = NaN;
    end 
        
    hsim(i,1) = hgrid_dist(ih_dist);
    hwsim(i,1) = lini(hgrid,hwmat(:,ib,jk,in),hsim(i,1));  
    leisuresim(i,1) = lini(hgrid,lmat(:,ib,jk,in),hsim(i,1));  
    consim(i,1) = lini(hgrid,cmat(:,ib,jk,in),hsim(i,1));    
    xsim(i,1) = lini(hgrid,xmat(:,ib,jk,in),hsim(i,1));  
    nxsim(i,1) = ((1+taux)*xsim(i,1))*nsim(i,1);    
    
    incsim(i,1) = w*hsim(i,1)*hwsim(i,1);
    bsim(i,1) = psicgrid(ib);
    
    txsim(i,1) = (xsim(i,1))/incsim(i,1);
    transim(i,1) = T + Trn(omega,nnow);
        
    hsim(i,2) = HKprodfn(Ah*kappagrid(jk),hsim(i,1),xsim(i,1),theta0,alpha1,alpha2); 
        
    Vtemp = zeros(nn,1);
    jb = bsimindkid(i);    
    jjk = kappasimindkidkid(i);
    for jn = 1:nn        
        Vtemp(jn) = lini(hgrid,EVmat(:,jb,jk,jn),hsim(i,2));
    end
    [~, in2] = max(Vtemp);
    
    incsim2(i,1) = w*hsim(i,2)*lini(hgrid,hwmat(:,jb,jjk,in2),hsim(i,2));    
        
end 
     
budgetbalance = (sum(incsim)+sum(transim)-sum(nxsim)-sum(consim))/NS;
incmean = mean(incsim);
nxmean = mean(nxsim);
conmean = mean(consim);

s5f = sprintf ( '  Checking individual budget   Extra inc =%8.3f   Avg(income) =%8.3f   Avg(consum) =%8.3f   Avg(invest) =%8.3f   '   ,budgetbalance,incmean,conmean,nxmean);
disp(s5f)

avg_educinv_inc = sum(xsim(nsim>0))/sum(incsim(nsim>0));

avg_LS = mean(hwsim);

% elasticity consistent with empirical evidence
% obtain income quintile
incpct5 = quantile(incsim,4);

incquin = zeros(NS,1);
for ii = 1:NS
    if incsim(ii) < incpct5(1)
        incquin(ii) = 1;
    elseif (incsim(ii)>=incpct5(1))&&(incsim(ii)<incpct5(2))
        incquin(ii) = 2;        
    elseif (incsim(ii)>=incpct5(2))&&(incsim(ii)<incpct5(3))
        incquin(ii) = 3;
    elseif (incsim(ii)>=incpct5(3))&&(incsim(ii)<incpct5(4))    
        incquin(ii) = 4;
    else
        incquin(ii) = 5;
    end
end

AvgI5 = zeros(5,1);
AvgI5a = zeros(5,1);
AvgF5 = zeros(5,1);
AvgX5 = zeros(5,1);
pctN = zeros(5,1);
pctNpos = zeros(5,1);

for k = 1:5
    % income by income quintile
    AvgI5(k) = mean(incsim(incquin==k));
    % fertility by income quintile
    AvgF5(k) = mean(nsim(incquin==k));
    % per-child investmnet by income quintile
    AvgX5(k) = mean(xsim(incquin==k&nsim>0));
    AvgI5a(k) = mean(incsim(incquin==k&nsim>0));
    
    pctN(k) = sum(incquin==k);
    pctNpos(k) = sum(incquin==k&nsim>0);
end

Wmat = zeros(5,5);
for j = 1:5
    Wmat(j,j) = pctN(j);
end

elast0 = wls1(log(AvgF5),log(AvgI5),Wmat);
elastx = wls1(log(AvgX5),log(AvgI5),Wmat);

AvgN05 = pctNpos./pctN;
AvgN05 = 1 - AvgN05;

invinc5 = AvgX5./AvgI5a;

prn = zeros(nn,1);
prn(1) = sum((nsim==0))/NS;
prn(2) = sum((nsim==1))/NS;
prn(3) = sum((nsim==2))/NS;
prn(4) = sum((nsim==3))/NS;
prn(5) = sum((nsim==4))/NS;

Giniinc = ginicoeff(incsim);

hpvec = 0;
hkvec = 0;
ns = 0;
for ii = 1:NS
    if nsim(ii) > 0
        ns = ns + 1;
        %hpvec(ns,1) = hsim(ii,1);
        hpvec(ns,1) = incsim(ii);
        hkvec(ns,1) = incsim2(ii);
    end
end

ige = ols1(log(hkvec(hpvec.*hkvec>0)),log(hpvec(hpvec.*hkvec>0)));

MinutesTotal = toc(simstart);
sf = sprintf( '************* Total time of simulation (seconds) = %8.0f ************  mu(nh) =%8.7f     mu(nh-20) =%8.7f', MinutesTotal,muh(nh_dist),muh(nh_dist-20));
disp(sf)

end

Tend = 8;  % Transition end period

wtd = 0.0;   % updating weight (dampening)
interval = 0;   % show info every x period

distoff0 = distoff;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% final steady state (Note: change manually)
if (perm==0)
    taux_new = taux;
    omega_new = omega;
    load('0-Baseline.mat')
else
    taux_new = taux;
    omega_new = omega;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% initializing transition path
EVmat_t = zeros(nh,npsi,nk,nn,Tend);
xmat_t = zeros(nh,npsi,nk,nn,Tend);
lmat_t = zeros(nh,npsi,nk,nn,Tend);
hwmat_t = zeros(nh,npsi,nk,nn,Tend);
cmat_t = zeros(nh,npsi,nk,nn,Tend);
nindmat_dist_t = zeros(nh_dist,npsi,nk,Tend);

avgfert_t = zeros(Tend,1);
Y_t = zeros(Tend,1);
TH_t = zeros(Tend,1);
L_t = zeros(Tend,1);
xmean_t = zeros(Tend,1);
txmean_t = zeros(Tend,1);
Hmean_t = zeros(Tend,1);
Htilde_t = zeros(Tend,1);
T_t = zeros(Tend,1);


mumatpre_t = zeros(nh_dist,nk,Tend);

EVmat_t(:,:,:,:,Tend) = EVmat;
xmat_t(:,:,:,:,Tend) = xmat;
lmat_t(:,:,:,:,Tend) = lmat;
hwmat_t(:,:,:,:,Tend) = hwmat;
cmat_t(:,:,:,:,Tend) = cmat;
nindmat_dist_t(:,:,:,Tend) = nindmat_dist;

avgfert_t(Tend) = avgfert;
Y_t(Tend) = Y;
TH_t(Tend) = THs;
L_t(Tend) = Ls;
xmean_t(Tend) = xmean;
txmean_t(Tend) = txmean;
Hmean_t(Tend) = Hmean;
Htilde_t(Tend) = H15;
T_t(Tend) = T;


mumatpre_t(:,:,Tend) = mumatpre;


% initial steady state
load('Baseline.mat')

EVmat_0 = EVmat;
xmat_0 = xmat;
lmat_0 = lmat;
hwmat_0 = hwmat;
cmat_0 = cmat;

avgfert_0 = avgfert;
Y_0 = Y;
TH_0 = THs;
L_0 = Ls;
xmean_0 = xmean;
txmean_0 = txmean;
Hmean_0 = Hmean;
Htilde_0 = H15;
T_0 = T;

mumatpre_0 = mumatpre;
nindmat_dist_0 = nindmat_dist;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Start to find equilibrium transitional dynamics
startsol = tic;

Hmean_t(1:Tend-1) = Hmean_t(Tend);
Htilde_t(1:Tend-1) = Htilde_t(Tend);
T_t(1:Tend-1) = T_t(Tend);

if distoff0==1
    Htilde_t(:) = H15;
end


Hmean_t_new = zeros(Tend,1);
T_t_new = zeros(Tend,1);
Hmean_t_new(Tend) = Hmean_t(Tend);
T_t_new(Tend) = T_t(Tend);

if (perm==1)
    % Policy: once and for all change as of t = 1
    taux_t = ones(Tend,1)*taux_new;
    omega_t = ones(Tend,1)*omega_new;
else
    % Temporary change in t=1
    taux_t = zeros(Tend,1);
    taux_t(1) = taux_new;
    omega_t = zeros(Tend,1);
    omega_t(1) = omega_new;
end


ssinfo1 = sprintf ( ' Period 0:     Hmean = %8.3f    H15 = %8.3f    Avg fertility = %8.3f', Hmean_0, Htilde_0, avgfert_0);
disp(ssinfo1) 
ssinfo2 = sprintf ( ' Period Tend:  Hmean = %8.3f    H15 = %8.3f    Avg fertility = %8.3f', Hmean_t(Tend), Htilde_t(Tend), avgfert_t(Tend));
disp(ssinfo2) 
   
iterationtd = 1; distancetd = 10000;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%           OUTER LOOP            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

while distancetd > tolout

    startIterout = tic;
    
    %%%%%%%%%%%%%%%%%
    % backward stage
    disp(' Now beginning Backward Stage') 
    startIter = tic;
    
    for t = (Tend-1):-1:1
        startt = tic;
        T = T_t(t);
        
        htilde = Htilde_t(t+1);   % Note: statistics from "next (i.e., t+1)" generation
        w = A;
        
        taux = taux_t(t);
        omega = omega_t(t);                        
                
        %%%%%%%%%%%%%%%%%%%%%%%%%%
        % Computing value functions and decision rules 
        parfor ih = 1:nh        
            hpnow = hgrid(ih);
            for in = 1:nn
                nnow = ngrid(in);
                phinow = phigrid(in);
                for ib = 1:npsi
                    psic = psicgrid(ib);
                    for jk = 1:nk
                        kappanow = kappagrid(jk);
                        if (in == 1)
                            % value of childless       
                            lmax = 1;

                            if (w*hpnow*lmax > T + Trn(omega,nnow))
                                nt0 = sum(tgrid<=lmax);
                        
                                objpos = @(les) ( psic*log(HES(w*hpnow*(lmax-les) + T + Trn(omega,nnow),0)) + psil*((les)^(1-gamma))/(1-gamma) );
        
                                vvectemp = zeros(nt0,1);
                                for it = 1:nt0
                                    if isreal(objpos(tgrid(it)))==1
                                        vvectemp(it) = objpos(tgrid(it));
                                    else
                                        vvectemp(it) = -inf;
                                    end
                                end
            
                                [Nval, minind] = max(vvectemp);  % maximizing objective fn
                                
                                lmat(ih,ib,jk,in) = tgrid(minind);
                                hwmat(ih,ib,jk,in) = lmax - tgrid(minind);
                                Vmat(ih,ib,jk,in) = Nval;
                                cmat(ih,ib,jk,in) = w*hpnow*hwmat(ih,ib,jk,in) + T + Trn(omega,nnow);
                                
                                xmat(ih,ib,jk,in) = 0;
        
                            else
                                % work full time but cannot afford positive consumption (due to lump-sum tax)     
                                Vmat(ih,ib,jk,in) = -inf;
                            end

                        else
                            % Conditional on having positive no. of children (n>0)

                            lmax = 1 - lambda*nnow;

                            nt0 = sum(tgrid<=lmax);

                            xmin = 0;
                                                        
                            % case 1: interior x > xmin
                            vvectemp1 = zeros(nt0,1);
                            cvectemp1 = zeros(nt0,1);
    
                            for it = 1:nt0
                                cmax = w*hpnow*(lmax-tgrid(it)) + T + Trn(omega,nnow) - (1+taux)*xmin*nnow;
    
                                if (cmax <= 0)
                                    vvectemp1(it) = -inf;
                                else
                                    objneg1 = @(c) - ( psic*log(HES(c, nnow)) + psil*(tgrid(it)^(1-gamma))/(1-gamma) ...
                                        + phinow*qualutil10t(HKprodfn(Ah*kappanow,hpnow,(w*hpnow*(lmax-tgrid(it)) + T + Trn(omega,nnow) - c )/((1+taux)*nnow),theta0,alpha1,alpha2),htilde,chi,scale,base) );
                                
                                    cvectemp1(it) = GSS(objneg1,0,cmax,tol);
                                    vvectemp1(it) = -objneg1(cvectemp1(it));
                                end
                            end
    
                            [Vval1, maxind1] = max(vvectemp1);  % maximizing over values

                            % case 2: x = xmin
                            vvectemp2 = zeros(nt0,1);
                                                        
                            objpos2 = @(les) ( psic*log(HES(w*hpnow*(lmax-les) + T + Trn(omega,nnow)- (1+taux)*xmin*nnow,nnow)) + psil*((les)^(1-gamma))/(1-gamma) ...
                                + phinow*qualutil10t(HKprodfn(Ah*kappanow,hpnow,xmin,theta0,alpha1,alpha2),htilde,chi,scale,base) );
    
                            for it = 1:nt0
                                cmax = w*hpnow*(lmax-tgrid(it)) + T + Trn(omega,nnow) - (1+taux)*xmin*nnow;
    
                                if (cmax <= 0)
                                    vvectemp2(it) = -inf;
                                else
                                    vvectemp2(it) = objpos2(tgrid(it));
                                end
                            end
    
                            [Vval2, maxind2] = max(vvectemp2);  % maximizing objective fn
    
                            if (isreal(Vval1)==0) && (isreal(Vval2)==0)
                                lmat(ih,ib,jk,in) = 0;
                                hwmat(ih,ib,jk,in) = 0;
                                xmat(ih,ib,jk,in) = 0;
                                cmat(ih,ib,jk,in) = 0;
                                Vmat(ih,ib,jk,in) = -inf;
    
                            elseif (Vval1>Vval2) 
                                lmat(ih,ib,jk,in) = tgrid(maxind1);   
                                hwmat(ih,ib,jk,in) = lmax - tgrid(maxind1);
                                xmat(ih,ib,jk,in) = (w*hpnow*(lmax-tgrid(maxind1)) + T + Trn(omega,nnow) - cvectemp1(maxind1) )/((1+taux)*nnow);
                                cmat(ih,ib,jk,in) = cvectemp1(maxind1);
                                Vmat(ih,ib,jk,in) = Vval1;
                            else
                                lmat(ih,ib,jk,in) = tgrid(maxind2);   
                                hwmat(ih,ib,jk,in) = lmax - tgrid(maxind2);
                                xmat(ih,ib,jk,in) = xmin;
                                cmat(ih,ib,jk,in) = w*hpnow*(lmax-tgrid(maxind2)) + T + Trn(omega,nnow)- (1+taux)*xmin*nnow;
                                Vmat(ih,ib,jk,in) = Vval2;
                            end

                        end
                    end
                end
            end
        end
        
        % Obtain expected utility
        % expectation w.r.t. productivity         
        EVtemp = zeros(nh,npsi,nk,nn);
        for ih = 1:nh
            for ib = 1:npsi                
                for in = 1:nn
                    for ik = 1:nk
                        EVtempval = 0;
                        for jk = 1:nk
                            EVtempval = EVtempval + kappaprmat(ik,jk)*Vmat(ih,ib,jk,in);
                        end
                        EVtemp(ih,ib,ik,in) = EVtempval;
                    end
                end
            end            
        end
        
        EVmat = EVtemp;
           
        
        % Fertility decision   
        for ih = 1:nh
            for ib = 1:npsi  
                for ik = 1:nk
                    [~, nindmat(ih,ib,ik)] = max(EVmat(ih,ib,ik,:));
                    nmat(ih,ib,ik) = ngrid(nindmat(ih,ib,ik));                
                end
            end            
        end
        
        % KEY INFORMATION TO SAVE for computing distribution
        EVmat_t(:,:,:,:,t) = EVmat;
        xmat_t(:,:,:,:,t) = xmat;
        lmat_t(:,:,:,:,t) = lmat;
        hwmat_t(:,:,:,:,t) = hwmat;
        cmat_t(:,:,:,:,t) = cmat;
        
        
        endt = toc(startt);

        info = sprintf ( '   Period %4d      taux = %5.3f      psi = %5.4f      H15next = %5.3f      T0 = %7.3f      Time elapsed (sec) = %8.2f', t, taux, omega, htilde, T, endt);
        disp(info)

    end
    
    endIter = toc(startIter);
    sback = sprintf ( ' Backward stage completed     Time elapsed (sec) = %8.2f', endIter);
    disp(sback) 
    
    
    %%%%%%%%%%%%%%%
    % forward loop
    % distributional grid
    startIter = tic;
    disp(' Now beginning Forward Stage') 
    info = sprintf ( '   Period %4d   sum(mu) = %8.5f     Hmean = %7.3f     Avg n = %7.4f     xmean = %7.5f     T0 = %7.4f', 0, sum(mumatpre_0(:)), Hmean_0, avgfert_0, xmean_0,T_0);
    disp(info)
    % Note: assumption: policy change affects economy in the beginning of period 1
    mumatpre_t(:,:,1) = mumatpre_0;    % same as initial steady state
    for t = 1:(Tend-1)
        taux = taux_t(t);
        omega = omega_t(t);
        
        % Note: important to distinguish hgrid today vs tomorrow        
        mumatpre = mumatpre_t(:,:,t);
        xmat = xmat_t(:,:,:,:,t);
        EVmat = EVmat_t(:,:,:,:,t);

        % conditional on being able to have kid + ability draw
        jhmat = zeros(nh_dist,npsi,nk,nk);
        whmat = zeros(nh_dist,npsi,nk,nk);

        Tmumatpre = zeros(nh_dist,nk);


        parfor ih_dist = 1:nh_dist     
            hpnow = hgrid_dist(ih_dist); 
            for ik = 1:nk                            
                for ib = 1:npsi                            
                    % 1. fertility
                    % obtain conditional values on hgrid_dist
                    valvectemp = zeros(nn,1);
                    for in = 1:nn
                        valvectemp(in,1) = lini(hgrid,EVmat(:,ib,ik,in),hpnow);                            
                    end
                    % find maximum index for n choice
                    [~ , maxindn] = max(valvectemp);
                    nindmat_dist(ih_dist,ib,ik) = maxindn;                        
                    
                    for jk = 1:nk
                        kappakid = kappagrid(jk); 
                        % 2. private education spending
                        xtemp = lini(hgrid,xmat(:,ib,jk,maxindn),hpnow);

                        % 3. then find implied h'                        
                        hnexttemp = HKprodfn(Ah*kappakid,hpnow,xtemp,theta0,alpha1,alpha2);

                        % finding indices and weights
                        if hnexttemp <= hgrid_dist(1)
                            jhmat(ih_dist,ib,ik,jk) = 1;
                            whmat(ih_dist,ib,ik,jk) = 1;
                            
                        elseif hnexttemp >= hgrid_dist(nh_dist)
                            jhmat(ih_dist,ib,ik,jk) = nh_dist - 1;
                            whmat(ih_dist,ib,ik,jk) = 0;
                            
                        else
                            jhmat(ih_dist,ib,ik,jk) = sum(hgrid_dist<hnexttemp);
                            whmat(ih_dist,ib,ik,jk) = (hgrid_dist(jhmat(ih_dist,ib,ik,jk)+1) - hnexttemp)/(hgrid_dist(jhmat(ih_dist,ib,ik,jk)+1) - hgrid_dist(jhmat(ih_dist,ib,ik,jk)));

                        end

                    end
                end                    
            end
        end
        
        
        for ih_dist = 1:nh_dist
            for ik = 1:nk
                if mumatpre(ih_dist,ik) > 0
                    for ib = 1:npsi                
                        muval = mumatpre(ih_dist,ik)*prpsic(ib);
                        % shocks realized
                        for jk = 1:nk
                            jh = jhmat(ih_dist,ib,ik,jk);
                            wgt_hnext = whmat(ih_dist,ib,ik,jk);
                            Tmumatpre(jh,jk) = Tmumatpre(jh,jk) + kappaprmat(ik,jk)*wgt_hnext*ngrid(nindmat_dist(ih_dist,ib,ik))*muval;
                            Tmumatpre(jh+1,jk) = Tmumatpre(jh+1,jk) + kappaprmat(ik,jk)*(1-wgt_hnext)*ngrid(nindmat_dist(ih_dist,ib,ik))*muval;                                
                        end
                    end                        
                end
            end            
        end
        
        musum = sum(mumatpre(:));

        mumat0 = zeros(nh_dist,npsi,nk);
        for ih_dist = 1:nh_dist
            for ik = 1:nk
                for ib = 1:npsi
                    mumat0(ih_dist,ib,ik) = prpsic(ib)*mumatpre(ih_dist,ik);
                end
            end
        end


        % scaling Tmumat
        avgfert = sum(sum(sum(ngrid(nindmat_dist).*mumat0)));
        avgfert_t(t) = avgfert;
        popgrowth = avgfert/2;
        Tmumatpre = Tmumatpre/avgfert;
        
        % computing aggregate factor supplies       
                
        % integrating out kappa to obtain marginal distribution of h
        muh = zeros(nh_dist,1);
        for ih_dist = 1:nh_dist
            muh(ih_dist) = sum(mumatpre(ih_dist,:));
        end        
        
        % unconditional mean; updating distributional info
        Hmean = hgrid_dist*muh;

        % top 15 average        
        cumh = cumsum(muh);
        topind = sum(cumh<pct_target) + 1;  


        muhtop = muh(topind:nh_dist);
        hgridtop = hgrid_dist(topind:nh_dist);
        % adjustment
        muhtop(1) = muhtop(1) - (pct_target-cumh(topind-1));

        H15 = hgridtop*muhtop/sum(muhtop);

        if (distoff0==0)
            Htilde_t(t) = H15;
        end
        Hmean_t_new(t) = Hmean;       
        
        
        Tnew = 0;
        xmeant = 0;
        for ih_dist = 1:nh_dist   
            hpnow = hgrid_dist(ih_dist);
            for ik = 1:nk
                if mumatpre(ih_dist,ik) > 0
                    for ib = 1:npsi
                        intemp = nindmat_dist(ih_dist,ib,ik);
                        % taking care of kappa
                        for jk = 1:nk
                            muval = prpsic(ib)*kappaprmat(ik,jk)*mumatpre(ih_dist,ik);

                            hwtemp = lini(hgrid,hwmat(:,ib,jk,intemp),hpnow);
                            xtemp = lini(hgrid,xmat(:,ib,jk,intemp),hpnow);

                            xmeant = xmeant + xtemp*muval;
                            Tnew = Tnew + ( taux*xtemp*ngrid(intemp) - (Trn(omega,ngrid(intemp))) )*muval;   
                        end
                    end
                end  
            end        
        end

        T_t_new(t) = Tnew;
        xmean_t(t) = xmeant;
        
        nindmat_dist_t(:,:,:,t) = nindmat_dist;

        if t < (Tend -1)
            mumatpre_t(:,:,t+1) = Tmumatpre;
        end
                
                
        info = sprintf ( '   Period %4d   sum(mu) = %8.5f     Hmean = %7.3f     Avg n = %7.4f     xmean = %7.5f     T0 = %7.5f', t, musum, Hmean, avgfert, xmeant, Tnew);
        disp(info)
        
    end
    
    infofinal = sprintf ( '   Period %4d   sum(mu) = %8.5f     Hmean = %7.3f     Avg n = %7.4f     xmean = %7.5f     T0 = %7.5f', Tend, 1.0, Hmean_t(Tend), avgfert_t(Tend), xmean_t(Tend), T_t(Tend));
    disp(infofinal)
    
    endIter = toc(startIter);
    sforward = sprintf ( ' Forward stage completed    Time elapsed (sec) = %8.2f', endIter);
    disp(sforward) 
    
    distanceH = max(abs(log(Hmean_t_new)-log(Hmean_t)));    
    distanceT = max(abs(T_t_new-T_t));
    distanceK = max(abs(T_t_new(Tend-1)-T_t_new(Tend)));
    
    if distoff0==1
        distancetd = distanceT;
    else
        distancetd = max(distanceH,distanceT);    
    end
    
    iterinfo = sprintf ( 'Finishing Outerloop Iteration %4d     distanceH =%7.5f    distanceT =%7.5f    distanceK =%7.5f', iterationtd, distanceH, distanceT, distanceK);
    disp(iterinfo) 
    disp(' ')
    
    % update with dampening 
    Hmean_t(1:Tend-1) = wtd*Hmean_t(1:Tend-1) + (1-wtd)*Hmean_t_new(1:Tend-1);    
    
    T_t(1:Tend-1) = T_t_new(1:Tend-1);
        
    iterationtd = iterationtd + 1;
    if iterationtd > 20
        break
    end
end
error= 100*log(xmean_t(Tend)/xmean_t(Tend-1));
se = sprintf( '***Terminal error (percent)= %6.3f ', error);
disp(se)  

Minutes = toc(startsol)/60;
sf = sprintf( '***************************** Minutes elapsed= %8.0f *****************************', Minutes);
disp(sf)  



% obtain aggregate factor supply over time

for t = 1:Tend
    mumatpre = mumatpre_t(:,:,t);
    hwmat = hwmat_t(:,:,:,:,t);
    xmat = xmat_t(:,:,:,:,t);
    nindmat_dist = nindmat_dist_t(:,:,:,t);

    THs = 0;
    Ls = 0;
    xmean = 0;
    txmean = 0;
    
    Hmean = 0;
        
    for ih_dist = 1:nh_dist    
        hpnow = hgrid_dist(ih_dist);
        for ik = 1:nk
            if mumatpre(ih_dist,ik) > 0
                for ib = 1:npsi
                    intemp = nindmat_dist(ih_dist,ib,ik);
                    % taking care of kappa shocks
                    for jk = 1:nk                        
                        muval = prpsic(ib)*kappaprmat(ik,jk)*mumatpre(ih_dist,ik);

                        hwtemp = lini(hgrid,hwmat(:,ib,jk,intemp),hpnow);
                        xtemp = lini(hgrid,xmat(:,ib,jk,intemp),hpnow);
                       
                        THs = THs + hwtemp*muval;
                        Ls = Ls + hpnow*hwtemp*muval;
                        xmean = xmean + xtemp*muval;    
                        txmean = txmean + ngrid(intemp)*xtemp*muval;  
                        Hmean = Hmean + hpnow*muval;
                    end
                    
                end
            end  
        end        
    end
    Hmean_t(t) = Hmean;      
    TH_t(t) = THs;
    L_t(t) = Ls;
    xmean_t(t) = xmean;
    txmean_t(t) = txmean;
    Y_t(t) = A*Ls;
    
end

% Calculating welfare based on value function

% Initial steady state
mumatpre = mumatpre_0;
EVmat = EVmat_0;
nindmat_dist = nindmat_dist_0;

AvgU0 = 0;
AvgNegU0 = 0;

% estimate the function for logc as a function of logh in steady state

yvec = consim;
xvec1 = hsim(:,1);
xvec2 = bsim;
xvec3 = kappagrid(kappasimind)';
xvec4 = kappagrid(kappasimindkid)';
XX = [ones(length(yvec),1) log(xvec1) log(xvec2) log(xvec3) log(xvec4)];

bvec = regress(log(yvec),XX);
b1 = bvec(1);
b2 = bvec(2);
b3 = bvec(3);
b4 = bvec(4);
b5 = bvec(5);


sumNeg = 0;
sumb = 0;
for ih_dist = 1:nh_dist
    for ik = 1:nk        
        if mumatpre(ih_dist,ik) > 0            
            for ib = 1:npsi                            
                for jk = 1:nk
                    Negcoeff = exp(b1 + b2*log(hgrid_dist(ih_dist)) + b3*log(psicgrid(ib)) + b4*log(kappagrid(ik)) + b5*log(kappagrid(jk)) );
                    
                    Negcoeff = Negcoeff/psicgrid(ib);
                    
                    muval = prpsic(ib)*kappaprmat(ik,jk)*mumatpre(ih_dist,ik);
                    
                    sumb = sumb + Negcoeff*psicgrid(ib)*muval;
                    AvgU0 = AvgU0 + lini(hgrid,EVmat(:,ib,ik,nindmat_dist(ih_dist,ib,ik)),hgrid_dist(ih_dist))*muval;
                    AvgNegU0 = AvgNegU0 + Negcoeff*lini(hgrid,EVmat(:,ib,ik,nindmat_dist(ih_dist,ib,ik)),hgrid_dist(ih_dist))*muval;
                    sumNeg = sumNeg + Negcoeff*muval;            
                end
            end            
        end
    end
end
AvgNegU0 = AvgNegU0/sumNeg;
AvgbNeg = sumb/sumNeg;


% Over the transition
AvgUt = zeros(Tend,1);
AvgNegUt = zeros(Tend,1);
c_t = zeros(Tend,1);

for t = 1:Tend
    mumatpre = mumatpre_t(:,:,t);
    EVmat = EVmat_t(:,:,:,:,t);
    nindmat_dist = nindmat_dist_t(:,:,:,t);
     
    sumNeg = 0;
    sumb = 0;
    AvgUtemp=0;
    AvgNegUtemp=0;
    for ih_dist = 1:nh_dist
        for ik = 1:nk        
            if mumatpre(ih_dist,ik) > 0            
                for ib = 1:npsi                            
                    for jk = 1:nk
                        Negcoeff = exp(b1 + b2*log(hgrid_dist(ih_dist)) + b3*log(psicgrid(ib)) + b4*log(kappagrid(ik)) + b5*log(kappagrid(jk)) );
                        
                        Negcoeff = Negcoeff/psicgrid(ib);
                        
                        muval = prpsic(ib)*kappaprmat(ik,jk)*mumatpre(ih_dist,ik);
                        
                        sumb = sumb + Negcoeff*psicgrid(ib)*muval;
                        AvgUtemp = AvgUtemp + lini(hgrid,EVmat(:,ib,ik,nindmat_dist(ih_dist,ib,ik)),hgrid_dist(ih_dist))*muval;
                        AvgNegUtemp = AvgNegUtemp + Negcoeff*lini(hgrid,EVmat(:,ib,ik,nindmat_dist(ih_dist,ib,ik)),hgrid_dist(ih_dist))*muval;
                        sumNeg = sumNeg + Negcoeff*muval;            
                    end
                end            
            end
        end
    end
    
    AvgUt(t) = AvgUtemp;
    AvgNegUt(t) = AvgNegUtemp/sumNeg;
        
end

if (negishi==1)
% Negishi weights
objval = -AvgNegUt(1);
else    
% Equal weights
objval = -AvgUt(1);
end

taux = taux_t(1);
omega = omega_t(1);
T = T_t(1);


if (option==0)

% Simulation (to obtain first-gen statistics)

mumatpre = mumatpre_t(:,:,1);
nindmat_dist = nindmat_dist_t(:,:,:,1);


%%%%%%%%%%%%
%Simulation
s = RandStream('mt19937ar','Seed',1);
RandStream.setGlobalStream(s);

% random sampling from mu_initial
mu0dist = reshape(mumatpre,nh_dist*nk,1);
mu0name = linspace(1,nh_dist*nk,nh_dist*nk);
distind = randsample(s,mu0name,NS,true,mu0dist);
hdistsimind = zeros(NS,1);
kappasimind = zeros(NS,1);

for i = 1:NS    
    hdistsimind(i,1) = rem(distind(i),nh_dist);
    if rem(distind(i),nh_dist) == 0
        hdistsimind(i,1) = nh_dist;
    end
    kappasimind(i,1) = fix((distind(i)-1)/nh_dist) + 1;
end

bname = linspace(1,npsi,npsi);
bsimind = randsample(s,bname,NS,true,prpsic);
bsimindkid = randsample(s,bname,NS,true,prpsic);

% kappakid random draw
kappaname = linspace(1,nk,nk);
kappasimindkid = zeros(NS,1);
kappasimindkidkid = zeros(NS,1);
for i = 1:NS
    kappasimindkid(i) = randsample(s,kappaname,1,true,kappaprmat(kappasimind(i),:));
end
for i = 1:NS
    kappasimindkidkid(i) = randsample(s,kappaname,1,true,kappaprmat(kappasimindkid(i),:));
end


% Simulating samples
nsim = zeros(NS,1);           % fertility
nsimpos = zeros(NS,1);        % fertility (with zero replaced with NaN)
child0 = zeros(NS,1);         % childlessness indicator

hwsim = zeros(NS,1);           % labor supply 
consim = zeros(NS,1);
bsim = zeros(NS,1);

xsim = zeros(NS,1);           % parental investment
txsim = zeros(NS,1);          % per child parental money investment expenditure/income (for calibration)
nxsim = zeros(NS,1);          % total parental money investment expenditure (to check market clearing)

hsim = zeros(NS,2);           % parent's and children's human capital

incsim = zeros(NS,1);      % family income

transim = zeros(NS,1);
% 12t
collegesim = zeros(NS,1);


for i = 1:NS
    ih_dist = hdistsimind(i);
    ib = bsimind(i);
    ik = kappasimind(i);  
    jk = kappasimindkid(i);

    nnow = ngrid(nindmat_dist(ih_dist,ib,ik));
    in = nindmat_dist(ih_dist,ib,ik);
    
    nsim(i,1) = nnow;
    nsimpos(i,1) = nnow;
    if nnow == 0
        child0(i,1) = 1;
        nsimpos(i,1) = NaN;
    end 
        
    hsim(i,1) = hgrid_dist(ih_dist);
    % v12
    hwsim(i,1) = lini(hgrid,hwmat(:,ib,jk,in),hsim(i,1));      
    consim(i,1) = lini(hgrid,cmat(:,ib,jk,in),hsim(i,1));    
    xsim(i,1) = lini(hgrid,xmat(:,ib,jk,in),hsim(i,1));  
    nxsim(i,1) = ((1+taux)*xsim(i,1))*nsim(i,1);    
    
    incsim(i,1) = w*hsim(i,1)*hwsim(i,1);
    bsim(i,1) = psicgrid(ib);
    
    txsim(i,1) = (xsim(i,1))/incsim(i,1);
    transim(i,1) = T + Trn(omega,nnow);
        
    hsim(i,2) = HKprodfn(Ah*kappagrid(jk),hsim(i,1),xsim(i,1),theta0,alpha1,alpha2); 
       
    collegesim(i,1) = max(0, 1 - exp(-scale*(hsim(i,2) + base - chi*htilde)));        
end 

incpct5 = quantile(incsim,4);

incquin = zeros(NS,1);
for ii = 1:NS
    if incsim(ii) < incpct5(1)
        incquin(ii) = 1;
    elseif (incsim(ii)>=incpct5(1))&&(incsim(ii)<incpct5(2))
        incquin(ii) = 2;        
    elseif (incsim(ii)>=incpct5(2))&&(incsim(ii)<incpct5(3))
        incquin(ii) = 3;
    elseif (incsim(ii)>=incpct5(3))&&(incsim(ii)<incpct5(4))    
        incquin(ii) = 4;
    else
        incquin(ii) = 5;
    end
end


AvgI5 = zeros(5,1);
AvgI5a = zeros(5,1);
AvgF5 = zeros(5,1);
AvgX5 = zeros(5,1);
pctN = zeros(5,1);
pctNpos = zeros(5,1);
AvgCol5 = zeros(5,1);
AvgColNum5 = zeros(5,1);


for k = 1:5
    % income by income quintile
    AvgI5(k) = mean(incsim(incquin==k));
    % fertility by income quintile
    AvgF5(k) = mean(nsim(incquin==k));
    % per-child investmnet by income quintile
    AvgX5(k) = mean(xsim(incquin==k&nsim>0));
    AvgI5a(k) = mean(incsim(incquin==k&nsim>0));
    
    pctN(k) = sum(incquin==k);
    pctNpos(k) = sum(incquin==k&nsim>0);

    % col prob by income quintile
    AvgCol5(k) = sum(collegesim(incquin==k).*nsim(incquin==k))/sum(nsim(incquin==k));

    % col number by income quintile
    AvgColNum5(k) = sum(collegesim(incquin==k).*nsim(incquin==k));

end
AvgN05 = pctNpos./pctN;
AvgN05 = 1 - AvgN05;

% Table 11
Avgfertopt = mean(nsim);
AvgF5opt = AvgF5;
nsimopt = nsim;
AvgN05opt = AvgN05;
AvgX5opt = AvgX5;
xsimopt = xsim;
AvgCol5opt = AvgCol5;
AvgColNum5opt = AvgColNum5;
pctNopt = pctN;
collegesimopt = collegesim;

load Baseline.mat avgfert AvgF5 nsim AvgN05 AvgX5 xsim AvgCol5 AvgColNum5 pctN collegesim

ttle = sprintf( '   ');
    disp(ttle)
    ttle = sprintf( '----------------------------  Table 11  ----------------------------');
    disp(ttle)
fertdisp = sprintf ( '   Fertility      Baseline:   1st =%6.2f  2nd =%6.2f  3rd =%6.2f  4th =%6.2f  5th =%6.2f       All =%6.2f', AvgF5(1),AvgF5(2),AvgF5(3),AvgF5(4),AvgF5(5),avgfert);
disp(fertdisp)
fertdisp = sprintf ( '                  Optimal :   1st =%6.2f  2nd =%6.2f  3rd =%6.2f  4th =%6.2f  5th =%6.2f       All =%6.2f', AvgF5opt(1),AvgF5opt(2),AvgF5opt(3),AvgF5opt(4),AvgF5opt(5),Avgfertopt);
disp(fertdisp)
fertdisp = sprintf ( '                  Pct chg :   1st =%6.1f  2nd =%6.1f  3rd =%6.1f  4th =%6.1f  5th =%6.1f       All =%6.1f', 100*((AvgF5opt(1)/AvgF5(1))-1),100*((AvgF5opt(2)/AvgF5(2))-1),100*((AvgF5opt(3)/AvgF5(3))-1),100*((AvgF5opt(4)/AvgF5(4))-1),100*((AvgF5opt(5)/AvgF5(5))-1),100*((mean(nsimopt)/avgfert)-1));
disp(fertdisp)
fert2disp = sprintf ( '   Childless(pct) Baseline:   1st =%6.1f  2nd =%6.1f  3rd =%6.1f  4th =%6.1f  5th =%6.1f       All =%6.1f', 100*AvgN05(1),100*AvgN05(2),100*AvgN05(3),100*AvgN05(4),100*AvgN05(5),100*sum(nsim==0)/NS);
disp(fert2disp)
fert2disp = sprintf ( '                  Optimal :   1st =%6.1f  2nd =%6.1f  3rd =%6.1f  4th =%6.1f  5th =%6.1f       All =%6.1f', 100*AvgN05opt(1),100*AvgN05opt(2),100*AvgN05opt(3),100*AvgN05opt(4),100*AvgN05opt(5),100*sum(nsimopt==0)/NS);
disp(fert2disp)
fert2disp = sprintf ( '                  Pct chg :   1st =%6.1f  2nd =%6.1f  3rd =%6.1f  4th =%6.1f  5th =%6.1f       All =%6.1f', 100*(AvgN05opt(1)-AvgN05(1)),100*(AvgN05opt(2)-AvgN05(2)),100*(AvgN05opt(3)-AvgN05(3)),100*(AvgN05opt(4)-AvgN05(4)),100*(AvgN05opt(5)-AvgN05(5)),100*(sum(nsimopt==0)/NS-sum(nsim==0)/NS));
disp(fert2disp)
invdisp = sprintf ( '   x per child    Baseline:   1st =%6.3f  2nd =%6.3f  3rd =%6.3f  4th =%6.3f  5th =%6.3f       All =%6.3f', AvgX5(1),AvgX5(2),AvgX5(3),AvgX5(4),AvgX5(5),mean(xsim(nsim>0)));
disp(invdisp)
invdisp = sprintf ( '                  Optimal :   1st =%6.3f  2nd =%6.3f  3rd =%6.3f  4th =%6.3f  5th =%6.3f       All =%6.3f', AvgX5opt(1),AvgX5opt(2),AvgX5opt(3),AvgX5opt(4),AvgX5opt(5),mean(xsimopt(nsimopt>0)));
disp(invdisp)
invdisp = sprintf ( '                  Pct chg :   1st =%6.1f  2nd =%6.1f  3rd =%6.1f  4th =%6.1f  5th =%6.1f       All =%6.1f', 100*((AvgX5opt(1)/AvgX5(1))-1),100*((AvgX5opt(2)/AvgX5(2))-1),100*((AvgX5opt(3)/AvgX5(3))-1),100*((AvgX5opt(4)/AvgX5(4))-1),100*((AvgX5opt(5)/AvgX5(5))-1),100*(mean(xsimopt(nsimopt>0))/mean(xsim(nsim>0))-1));
disp(invdisp)
coldisp = sprintf ( '   No. col child  Baseline:   1st =%6.2f  2nd =%6.2f  3rd =%6.2f  4th =%6.2f  5th =%6.2f       All =%6.2f', AvgColNum5(1)/pctN(1),AvgColNum5(2)/pctN(2),AvgColNum5(3)/pctN(3),AvgColNum5(4)/pctN(4),AvgColNum5(5)/pctN(5),sum(collegesim.*nsim)/NS);
disp(coldisp)
coldisp = sprintf ( '                  Optimal :   1st =%6.2f  2nd =%6.2f  3rd =%6.2f  4th =%6.2f  5th =%6.2f       All =%6.2f', AvgColNum5opt(1)/pctNopt(1),AvgColNum5opt(2)/pctNopt(2),AvgColNum5opt(3)/pctNopt(3),AvgColNum5opt(4)/pctNopt(4),AvgColNum5opt(5)/pctNopt(5),sum(collegesimopt.*nsimopt)/NS);
disp(coldisp)
coldisp = sprintf ( '                  Pct chg :   1st =%6.1f  2nd =%6.1f  3rd =%6.1f  4th =%6.1f  5th =%6.1f       All =%6.1f', 100*(((AvgColNum5opt(1)/pctNopt(1))/(AvgColNum5(1)/pctN(1)))-1),100*(((AvgColNum5opt(2)/pctNopt(2))/(AvgColNum5(2)/pctN(2)))-1),100*(((AvgColNum5opt(3)/pctNopt(3))/(AvgColNum5(3)/pctN(3)))-1),100*(((AvgColNum5opt(4)/pctNopt(4))/(AvgColNum5(4)/pctN(4)))-1),100*(((AvgColNum5opt(5)/pctNopt(5))/(AvgColNum5(5)/pctN(5)))-1),100*(((sum(collegesimopt.*nsimopt))/(sum(collegesim.*nsim)))-1));
disp(coldisp)



end










    


