%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% "Status Externalities in Education and Low Birth Rates in Korea"
% Seongeun Kim, Michele Tertilt, and Minchul Yum

% Tournament Model (Section 8)
% Replication commands
% note: running the code sequentially ensure that all results are replicated
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;

% Parameters externally calibrated
gamma = 2.0;
lambda = 0.057*18/25;   % per kid parental time = 5.7 hrs per week

% Parameters internally calibrated
chi = 0.28277645;      
scale = 0.85750924;
base = 0.41953602;
theta0 = 0.26593892;
Ah = 6.0549898;         
psil = 1.5662334;   
psicsd = 0.42946987;
phi1 = 1.216828;
phi2add = 0.75982003;
phi3add = 0.45397054;
kappasd = 0.50788069;
alpha1 =  0.66176023;   
kapparho = 0.2508406;

% policy parameters
taux= 0.0;
omega = 0.0;
eta = 0.0;

% 1. solve baseline steady-state and save steady state results; Table A13 and Figure A14a
Prog_TourSS(0,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,base,gamma,kapparho,kappasd,alpha1,theta0,chi,scale,taux,omega,0);

% 2. solve the model with policies
% Pro-natal transfers
Prog_TourSS(1,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,base,gamma,kapparho,kappasd,alpha1,theta0,chi,scale,taux,0.01,0);
Prog_TourSS(1,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,base,gamma,kapparho,kappasd,alpha1,theta0,chi,scale,taux,0.02,0);
% Education tax
Prog_TourSS(1,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,base,gamma,kapparho,kappasd,alpha1,theta0,chi,scale,0.1,omega,0);
Prog_TourSS(1,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,base,gamma,kapparho,kappasd,alpha1,theta0,chi,scale,0.2,omega,0);

% 3. solve for the optimal policy numerically (Section 8) and display optimal policy
negishi = 1;
perm = 1;
objfn = @(x) Prog_TourTR(1,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,base,gamma,kapparho,kappasd,alpha1,theta0,chi,scale,x(1),x(2),negishi,perm,0);

x0(1) = log(0.37);
x0(2) = log(0.025);

minparvec = fminsearch(objfn,x0,optimset('TolX',1e-6,'TolFun',1e-6,'Display','iter','FunValCheck','on','MaxFunEvals',1000,'MaxIter',1000));
mom1 = sprintf( 'Optimal policy: taux=%6.3f   phi=%7.4f  ',exp(minparvec(1)),exp(minparvec(2)));
disp(mom1)

% 4. obtain steady state with optimal permanent policy with Negishi weights and display Table 11
negishi = 1;
perm = 1;
Prog_TourTR(0,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,base,gamma,kapparho,kappasd,alpha1,theta0,chi,scale,log(0.363032677017507),log(0.0244459402891797),negishi,perm,0);

% 5. Figure A14b
Prog_TourSS(2,Ah,psicsd,psil,lambda,phi1,phi2add,phi3add,base,gamma,kapparho,kappasd,alpha1,theta0,chi,scale,0.363032677017507,0.0244459402891797,0);
