

* install necessary packages for replication
ssc install ginidesc, replace
ssc install cleanplots, replace
ssc install boottest, replace
ssc install estout, replace
ssc install fillmissing, replace


* generate datasets for analysis from raw data

clear

* location of data

cd "$folder"


********************************************************************************
********************************************************************************
* KLIPS Data cleaning
********************************************************************************
********************************************************************************

quietly {

forval y=1/20 {  

local n=`y'
if `y'<10 {
local y "0`y'"
}

use "$folder\KLIPS\klips`y'h_i.dta", clear // `y'th survey data

keep if hwave`y'==1 // households participating in `y'th survey
gen year=`y'

/*=======================================================*/	
/* keep variables regarding demographics, income, wealth */
/*=======================================================*/	

local vlist "hhid* year" // basic variables for each household

* add following variables if they exist
foreach x of numlist 0141 0221/0235 0241/0255 0261/0275 0281/0295 0301/0315 0321/0335 0361/0375 0421/0435 0661/0675 0681/0695 {
	local newx "0`x'"
	capture confirm variable h`y'`newx'
	if !_rc {
			local vlist "`vlist' h`y'`newx'"
	}
}
foreach x of numlist 2102 2112/2116 2122/2126 2301 2313 2314 {
	capture confirm variable h`y'`x'
	if !_rc {
			local vlist "`vlist' h`y'`x'"
	}
}

keep `vlist'

/*
keep hhid`y'  /// household id
    h`y'0141 /// province
    h`y'0221-h`y'0235 /// personal id (pid)
    h`y'0241-h`y'0255 /// sex 1-m, 2-f
    h`y'0261-h`y'0275 /// relationship with the head of hh: 10:self, 11-19:children, 20:spouse 
    h`y'0281-h`y'0295 /// 1: solar calendar, 2: lunar
	h`y'0301-h`y'0315 /// birth year
	h`y'0361-h`y'0375 /// age (international)
	h`y'0421-h`y'0435 /// survey status: 1:continued 2:new 3:separated 4:dead
	h`y'0661-h`y'0675 /// education: 1:pre 2:none 3:elementary 4:middle 5:high 6:1y-college 7:4y-college 8:master 9:phd
	h`y'0681-h`y'0695 /// education: status 1: graduated 2:completed(w/o degree) 3:dropout 4:current 5:leave of absence
	h`y'2102   /// labor income (last year)
	h`y'2112-h`y'2116 /// financial income (last year)
	h`y'2122-h`y'2126 /// real estate income (last year)
	h`y'2301 // monthly average total expenditures (10,000 Won)
	h`y'2313 // monthly average expenditures for public education
	h`y'2314 // monthly average expenditures for private education
*/


/*==============================*/	
/* education of head and spouse */
/*==============================*/

gen edu_head_m=.
gen edu_head_f=.

forvalue i=1/15 {
local a=`i'+40  // sex 02-
local b=`i'+60  // relationshiop 02-
local c=`i'+60  // education 06-
local d=`i'+80  // graduation status 06-
replace edu_head_m=h`y'06`c' if h`y'02`a'==1 & (h`y'02`b'==10 | h`y'02`b'==20) & h`y'06`d'<3
replace edu_head_m=h`y'06`c'-1 if h`y'02`a'==1 & (h`y'02`b'==10 | h`y'02`b'==20) & h`y'06`d'>=3 
replace edu_head_f=h`y'06`c' if h`y'02`a'==2 & (h`y'02`b'==10 | h`y'02`b'==20) & h`y'06`d'<3
replace edu_head_f=h`y'06`c'-1 if h`y'02`a'==2 & (h`y'02`b'==10 | h`y'02`b'==20) & h`y'06`d'>=3 
}

recode edu_head_m -2/-1= 1 
recode edu_head_f -2/-1= 1 

/*==================================*/
/* number of children per household */
/*==================================*/
* count only surviving children

forvalue i=1/15 {
	local a=`i'+60
	gen child_`i'=(h`y'02`a'>=11 & h`y'02`a'<=19)
}
egen n_child_head=rowtotal(child_*)
drop child_*

/*=================*/	
/* age of children */
/*=================*/

forvalue i=1/15 {
local a=`i'+60
gen age_child_`i'=h`y'03`a' 
replace age_child_`i'=. if (h`y'02`a'<11 | h`y'02`a'>19)
}

egen min_age_child = rowmin(age_child_*)
egen max_age_child = rowmax(age_child_*)
drop age_child_*

/*========================*/	
/* age of head and spouse */
/*========================*/

gen age_head_m=.
gen age_head_f=.
gen birth_year_m=.
gen birth_year_f=.

if `n'==1 {
	forvalue i=1/9 {
	local a=`i'+40  // sex
	local b=`i'+60  // relationship
	local c=`i'+20  // birth month
	local d=`i'+80  // 1:solar calendar ,2:lunar
	local newi "0`i'"
	replace age_head_m=h`y'03`b' if h`y'02`a'==1 & (h`y'02`b'==10 | h`y'02`b'==20)
	replace age_head_f=h`y'03`b' if h`y'02`a'==2 & (h`y'02`b'==10 | h`y'02`b'==20)
	replace birth_year_m=h`y'03`newi' if h`y'02`a'==1 & (h`y'02`b'==10 | h`y'02`b'==20)
	replace birth_year_f=h`y'03`newi' if h`y'02`a'==2 & (h`y'02`b'==10 | h`y'02`b'==20)
	replace birth_year_m=birth_year_m+1 if h`y'02`d'==2 & (h`y'03`c'==11 | h`y'03`c'==12) // lunar->solar
	replace birth_year_f=birth_year_f+1 if h`y'02`d'==2 & (h`y'03`c'==11 | h`y'03`c'==12) // lunar->solar
	}
	forvalue i=10/15 {
	local a=`i'+40  // sex
	local b=`i'+60  // relationship
	local c=`i'+20  // birth month
	local d=`i'+80  // 1:solar calendar ,2:lunar
	replace age_head_m=h`y'03`b' if h`y'02`a'==1 & (h`y'02`b'==10 | h`y'02`b'==20)
	replace age_head_f=h`y'03`b' if h`y'02`a'==2 & (h`y'02`b'==10 | h`y'02`b'==20)
	replace birth_year_m=h`y'03`i' if h`y'02`a'==1 & (h`y'02`b'==10 | h`y'02`b'==20)
	replace birth_year_f=h`y'03`i' if h`y'02`a'==2 & (h`y'02`b'==10 | h`y'02`b'==20)
	replace birth_year_m=birth_year_m+1 if h`y'02`d'==2 & (h`y'03`c'==11 | h`y'03`c'==12) // lunar->solar
	replace birth_year_f=birth_year_f+1 if h`y'02`d'==2 & (h`y'03`c'==11 | h`y'03`c'==12) // lunar->solar
	}
}
else {
	forvalue i=1/9 {
	local a=`i'+40  // sex
	local b=`i'+60  // relationship
	local c=`i'+20  // survey status
	local d=`i'+80  // 1:solar calendar ,2:lunar
	local newi "0`i'"
	replace age_head_m=h`y'03`b' if h`y'02`a'==1 & (h`y'02`b'==10 | h`y'02`b'==20) & (h`y'04`c'==1 | h`y'04`c'==2)
	replace age_head_f=h`y'03`b' if h`y'02`a'==2 & (h`y'02`b'==10 | h`y'02`b'==20) & (h`y'04`c'==1 | h`y'04`c'==2)
	replace birth_year_m=h`y'03`newi' if h`y'02`a'==1 & (h`y'02`b'==10 | h`y'02`b'==20) & (h`y'04`c'==1 | h`y'04`c'==2)
	replace birth_year_f=h`y'03`newi' if h`y'02`a'==2 & (h`y'02`b'==10 | h`y'02`b'==20) & (h`y'04`c'==1 | h`y'04`c'==2)
	replace birth_year_m=birth_year_m+1 if h`y'02`d'==2 & (h`y'03`c'==11 | h`y'03`c'==12) // lunar->solar
	replace birth_year_f=birth_year_f+1 if h`y'02`d'==2 & (h`y'03`c'==11 | h`y'03`c'==12) // lunar->solar
	}
	forvalue i=10/15 {
	local a=`i'+40  // sex
	local b=`i'+60  // relationship
	local c=`i'+20  // survey status
	local d=`i'+80  // 1:solar calendar ,2:lunar
	replace age_head_m=h`y'03`b' if h`y'02`a'==1 & (h`y'02`b'==10 | h`y'02`b'==20) & (h`y'04`c'==1 | h`y'04`c'==2)
	replace age_head_f=h`y'03`b' if h`y'02`a'==2 & (h`y'02`b'==10 | h`y'02`b'==20) & (h`y'04`c'==1 | h`y'04`c'==2)
	replace birth_year_m=h`y'03`i' if h`y'02`a'==1 & (h`y'02`b'==10 | h`y'02`b'==20) & (h`y'04`c'==1 | h`y'04`c'==2)
	replace birth_year_f=h`y'03`i' if h`y'02`a'==2 & (h`y'02`b'==10 | h`y'02`b'==20) & (h`y'04`c'==1 | h`y'04`c'==2)
	replace birth_year_m=birth_year_m+1 if h`y'02`d'==2 & (h`y'03`c'==11 | h`y'03`c'==12) // lunar->solar
	replace birth_year_f=birth_year_f+1 if h`y'02`d'==2 & (h`y'03`c'==11 | h`y'03`c'==12) // lunar->solar
	}
}

recode age_head_m (-1=.)
recode age_head_f (-1=.)
recode birth_year_m (-1=.)
recode birth_year_f (-1=.)


/*========*/	 
/* Income */
/*========*/	
* unit=10,000won

* missing observations
foreach x of numlist 2102 2112/2116 2122/2126 {
capture recode `x' (-1=.)
}
* cleaning income
capture gen inc_e=h`y'2102 /*earned income*/
if _rc!=0 {
	gen inc_e=.
}
local vlist ""
foreach x of numlist 2112/2116 {
	capture confirm variable h`y'`x'
	if !_rc {
			local vlist "`vlist' h`y'`x'"
	}
}
capture egen inc_f=rowtotal(`vlist'),missing /*financial income*/
if _rc!=0 {
	gen inc_f=.
}
local vlist ""
foreach x of numlist 2122/2126 {
	capture confirm variable h`y'`x'
	if !_rc {
			local vlist "`vlist' h`y'`x'"
	}
}
capture egen inc_r=rowtotal(`vlist'),missing /*real estate income*/
if _rc!=0 {
	gen inc_r=.
}
 local vlist ""


* annual total income
egen inc=rowtotal(inc_e inc_f inc_r),missing

drop inc_*

//sum inc


/*================================================*/	
/* personal data on the household head and spouse */
/*================================================*/
* need to merge information in the personal data

* merge male head's personal information
gen pid=.
forvalue i=1/15 {
	local a=`i'+20 // pid
	local b=`i'+40 // sex
	local c=`i'+60 // relationship
	replace pid= h`y'02`a' if h`y'02`b'==1 & (h`y'02`c'==10 | h`y'02`c'==20)
}

if `y'<6 {
merge 1:1 pid hhid`y' using "$folder\KLIPS\klips`y'p_i", keepusing(p`y'1642 p`y'1672 p`y'0201 p`y'5501 p`y'1006 p`y'1031) 
// income(worker/nonworker), working status
drop if _merge==2
drop _merge

recode p`y'1642 p`y'1672 p`y'0201 p`y'1006 p`y'1031 (-1=.)

gen work_head_m = p`y'0201 // 1: hired 2: not hired
egen inc_head_m = rowtotal(p`y'1642 p`y'1672), missing  // personal income
egen hours_head_m = rowtotal(p`y'1006 p`y'1031), missing  // working hours per week

gen married_m = p`y'5501 // 1:never married 2:married with spouse 3:separated 4:divorce 5:widow(er)

drop pid p`y'1642 p`y'1672 p`y'0201 p`y'1006 p`y'1031
}
else if `y'>=6 {
merge 1:1 pid hhid`y' using "$folder\KLIPS\klips`y'p_i", keepusing(p`y'1642 p`y'1672 p`y'0201 p`y'1702 p`y'5501 p`y'1006 p`y'1031) 
// income(worker/nonworker), working status
drop if _merge==2
drop _merge

recode p`y'1642 p`y'1672 p`y'0201 p`y'1702 p`y'1006 p`y'1031 (-1=.)

gen work_head_m = p`y'0201 // 1: hired 2: not hired
egen inc_head_m = rowtotal(p`y'1642 p`y'1672), missing  // personal income
gen inc_head_m_yearly = p`y'1702 
egen hours_head_m = rowtotal(p`y'1006 p`y'1031), missing  // working hours per week

gen married_m = p`y'5501 

drop pid p`y'1642 p`y'1672 p`y'0201 p`y'1702 p`y'1006 p`y'1031
}

* merge female head's personal information
gen pid=.
forvalue i=1/15 {
	local a=`i'+20 // pid
	local b=`i'+40 // sex
	local c=`i'+60 // relationship
	replace pid= h`y'02`a' if h`y'02`b'==2 & (h`y'02`c'==10 | h`y'02`c'==20)
}

if `y'<6 {
merge 1:1 pid hhid`y' using "$folder\KLIPS\klips`y'p_i", keepusing(p`y'1642 p`y'1672 p`y'0201 p`y'5501 p`y'1006 p`y'1031) 
// income(worker/nonworker), working status, marriage status
drop if _merge==2
drop _merge

recode p`y'1642 p`y'1672 p`y'0201 p`y'5501 p`y'1006 p`y'1031 (-1=.)

gen work_head_f = p`y'0201 // 1: hired 2: not hired
egen inc_head_f = rowtotal(p`y'1642 p`y'1672), missing  // personal income
egen hours_head_f = rowtotal(p`y'1006 p`y'1031), missing  // working hours per week

recode work_head_f work_head_m (2=0)

gen married_f = p`y'5501 

drop pid p`y'1642 p`y'1672 p`y'0201 p`y'5501 p`y'1006 p`y'1031
}
else if `y'>=6 {
merge 1:1 pid hhid`y' using "$folder\KLIPS\klips`y'p_i", keepusing(p`y'1642 p`y'1672 p`y'0201  p`y'1702 p`y'5501 p`y'1006 p`y'1031) 
// income(worker/nonworker), working status, marriage status
drop if _merge==2
drop _merge

recode p`y'1642 p`y'1672 p`y'0201  p`y'1702 p`y'5501 p`y'1006 p`y'1031 (-1=.)

gen work_head_f = p`y'0201 // 1: hired 2: not hired
egen inc_head_f = rowtotal(p`y'1642 p`y'1672), missing  // personal income
gen inc_head_f_yearly = p`y'1702 
egen hours_head_f = rowtotal(p`y'1006 p`y'1031), missing  // working hours per week

recode work_head_f work_head_m (2=0)

gen married_f = p`y'5501 

drop pid p`y'1642 p`y'1672 p`y'0201  p`y'1702 p`y'5501 p`y'1006 p`y'1031
}

/*=================*/	
/* total educost */
/*=================*/

gen expenditure_month = h`y'2301
replace expenditure_month = . if expenditure_month<0

capture confirm variable h`y'2313
	if !_rc {
gen educost_pub_month = h`y'2313
replace educost_pub_month = . if expenditure_month<0
}

capture confirm variable h`y'2314
	if !_rc {
gen educost_priv_month = h`y'2314
replace educost_priv_month = . if expenditure_month<0
}

/*======*/	 
/* Save */
/*======*/

rename h`y'0141 province

local savelist "hhid`y' province year age_head* n_child* *_age_child inc* edu* married* hours* birth* expenditure*"
capture confirm variable educost_pub_month
if !_rc {
	local savelist "`savelist' educost*"
}
keep `savelist'

gen hhid=hhid`y'
drop hhid`y'

save temp`y'.dta, replace
}

/*=======*/	 
/* Merge */
/*=======*/

use temp01.dta, clear
forval y=2/20 {
if `y'<10 {
local y "0`y'"
}
append using temp`y'.dta
}
order hhid

label var hhid "household id"
label var year "1-20 (1998-2017)"
label var province "province"
label var age_head_m "male head age"
label var age_head_f "female head age"
label var n_child_head "number of children"
label var min_age_child "min age of children"
label var max_age_child "max age of children"
label var inc "household total income (10,000won,yearly)"
label var inc_head_m "male head earning (10,000won,monthly)"
label var inc_head_f "female head earning (10,000won,monthly)"
label var edu_head_m "male head education (5:high,6:2y-col,7:4y-col)"
label var edu_head_f "female head education (5:high,6:2y-col,7:4y-col)"
label var married_f "female head marriage status (1:never 2married 3separate 4divorce 5:widow)"
label var married_m "male head marriage status (1:never 2married 3separate 4divorce 5:widower)"
label var hours_head_m "male head hours of work"
label var hours_head_f "female head hours of work"
label var birth_year_m "male head birth year"
label var birth_year_f "female head birth year"
label var expenditure_month "total expenditirue (10,000won,monthly)"
label var educost_pub_month "expenditure on public education (10,000won,monthly)"
label var educost_priv_month "expenditure on private education (10,000won,monthly)"
label var inc_head_m_yearly "male head personal income (10,000won,yearly)"
label var inc_head_f_yearly "female head personal income (10,000won,yearly)"

xtset hhid year

}

save data_clean.dta, replace

qui forval y=1/20 {
if `y'<10 {
local y "0`y'"
}
erase temp`y'.dta
}



********************************************************************************
********************************************************************************
* Data cleaning for education costs per each child
********************************************************************************
********************************************************************************

quietly {

* variables change across surveys
* 3-5
foreach y of num 3/5 {

if `y'<10 {
local y "0`y'"
}

use "$folder\KLIPS\klips`y'h_i", clear

keep if hwave`y'==1

/*=================================*/	
/* education expenditure per child */
/*=================================*/

* age
local k=1
foreach age of varlist h`y'0361-h`y'0375 {
rename `age' age`k'
local ++k
}
* personal id
local l=1
foreach pid of varlist h`y'0221-h`y'0235 {
rename `pid' pid`l'
local ++l
}
* max # of children under investigation = 5
foreach n of numlist 1/5 {
gen chpid`n'=.
gen chage`n'=.
}
* variables for each child
foreach n of numlist 1/15 {
replace chpid1=pid`n' if h`y'1511==`n'
replace chage1=age`n' if h`y'1511==`n'
}
foreach n of numlist 1/15 {
replace chpid2=pid`n' if h`y'1611==`n'
replace chage2=age`n' if h`y'1611==`n'
}
foreach n of numlist 1/15 {
replace chpid3=pid`n' if h`y'1711==`n'
replace chage3=age`n' if h`y'1711==`n'
}
foreach n of numlist 1/15 {
replace chpid4=pid`n' if h`y'1811==`n'
replace chage4=age`n' if h`y'1811==`n'
}
foreach n of numlist 1/15 {
replace chpid5=pid`n' if h`y'1911==`n'
replace chage5=age`n' if h`y'1911==`n'
}

* type of private education for 5 children (type 0:parents,...,5:hagwon,...)
local i=1
foreach type1 in h`y'1516 h`y'1616 h`y'1716 h`y'1816 h`y'1916 {
capture confirm variable `type1' 
if !_rc {
rename `type1' type1`i'
local ++i
}
}
local i=1
foreach type2 in h`y'1520 h`y'1620 h`y'1720 h`y'1820 h`y'1920 {
capture confirm variable `type2' 
if !_rc {
rename `type2' type2`i'
local ++i
}
}
local i=1
foreach type3 in h`y'1524 h`y'1624 h`y'1724 h`y'1824 h`y'1924 {
capture confirm variable `type3' 
if !_rc {
rename `type3' type3`i'
local ++i
}
}
local i=1
foreach type4 in h`y'1528 h`y'1628 h`y'1728 h`y'1828 h`y'1928 {
capture confirm variable `type4' 
if !_rc {
rename `type4' type4`i'
local ++i
}
}
local i=1
foreach type5 in h`y'1532 h`y'1632 h`y'1732 h`y'1832 h`y'1932 {
capture confirm variable `type5' 
if !_rc {
rename `type5' type5`i'
local ++i
}
}
local i=1
foreach type6 in h`y'1536 h`y'1636 h`y'1736 h`y'1836 h`y'1936 {
capture confirm variable `type6' 
if !_rc {
rename `type6' type6`i'
local ++i
}
}
local i=1
foreach type7 in h`y'1538 h`y'1638 h`y'1738 h`y'1838 h`y'1938 {
capture confirm variable `type7' 
if !_rc {
rename `type7' type7`i'
local ++i
}
}
local i=1
foreach type8 in h`y'1540 h`y'1640 h`y'1740 h`y'1840 h`y'1940 {
capture confirm variable `type8' 
if !_rc {
rename `type8' type8`i'
local ++i
}
}
* cost of private education for 5 children 
local i=1
foreach cost1 in h`y'1519 h`y'1619 h`y'1719 h`y'1819 h`y'1919 {
capture confirm variable `cost1' 
if !_rc {
rename `cost1' cost1`i'
local ++i
}
}
local i=1
foreach cost2 in h`y'1523 h`y'1623 h`y'1723 h`y'1823 h`y'1923 {
capture confirm variable `cost2' 
if !_rc {
rename `cost2' cost2`i'
local ++i
}
}
local i=1
foreach cost3 in h`y'1527 h`y'1627 h`y'1727 h`y'1827 h`y'1927 {
capture confirm variable `cost3' 
if !_rc {
rename `cost3' cost3`i'
local ++i
}
}
local i=1
foreach cost4 in h`y'1531 h`y'1631 h`y'1731 h`y'1831 h`y'1931 {
capture confirm variable `cost4' 
if !_rc {
rename `cost4' cost4`i'
local ++i
}
}
local i=1
foreach cost5 in h`y'1535 h`y'1635 h`y'1735 h`y'1835 h`y'1935 {
capture confirm variable `cost5' 
if !_rc {
rename `cost5' cost5`i'
local ++i
}
}
local i=1
foreach cost6 in h`y'1537 h`y'1637 h`y'1737 h`y'1837 h`y'1937 {
capture confirm variable `cost6' 
if !_rc {
rename `cost6' cost6`i'
local ++i
}
}
local i=1
foreach cost7 in h`y'1539 h`y'1639 h`y'1739 h`y'1839 h`y'1939 {
capture confirm variable `cost7' 
if !_rc {
rename `cost7' cost7`i'
local ++i
}
}
local i=1
foreach cost8 in h`y'1541 h`y'1641 h`y'1741 h`y'1841 h`y'1941 {
capture confirm variable `cost8' 
if !_rc {
rename `cost8' cost8`i'
local ++i
}
}

* Number of private education lessons (For years 6, 12-20: whether taking private education or not)
rename h`y'1514 ifprivedu
recode ifprivedu 1/9=1    // 0: no priv. edu.; 1: at least one lession

* number of children
rename h`y'1502 sib_numb_before_college // missing or 1-5 (there is no zero)
//rename h`y'2002 sib_numb_college

* drop unnecessary variables
keep hhid`y' ch* type* cost* sib* ifprivedu

* reshape
#delimit ;
reshape long chpid chage 
type1 cost1 type2 cost2 type3 cost3 type4 cost4 type5 cost5 type6 cost6 type7 cost7 type8 cost8, i(hhid`y');
#delimit cr

drop if chpid==.

* sibling order (based on age)
gsort hhid`y' -chage
by hhid`y': gen sib_order = _n

* drop weird answers regarding number of children
by hhid`y': gen temp = _N
drop if temp~=sib_numb_before_college
drop temp

by hhid`y': egen sib_max = max(sib_order)
drop if sib_max~=sib_numb_before_college
drop sib_max

egen edu_numb=anycount(type*), values(1/21) /*private education types; 0: parents */

* total costs and number of private education per child
recode cost*(-1=.)
egen edu_totcost=rowtotal(cost*),missing /*expenditures for private education*/

* dealing with missing observations
replace edu_totcost=0 if edu_totcost==. & (ifprivedu==0 | edu_numb==0)


//sum edu_totcost
//tab edu_numb

keep hhid`y' chpid chage edu_totcost sib_order
rename hhid`y' hhid

save temp_educost_detail`y', replace
}

**********************************************
* there is only total costs in the 6th survey 
**********************************************
local y "06"

use "$folder\KLIPS\klips`y'h_i", clear

keep if hwave`y'==1

* age
local k=1
foreach age of varlist h`y'0361-h`y'0375 {
rename `age' age`k'
local ++k
}
* personal id
local l=1
foreach pid of varlist h`y'0221-h`y'0235 {
rename `pid' pid`l'
local ++l
}
* max # of children under investigation = 5
foreach n of numlist 1/5 {
gen chpid`n'=.
gen chage`n'=.
}
* variables for each child
foreach n of numlist 1/15 {
replace chpid1=pid`n' if h`y'1511==`n'
replace chage1=age`n' if h`y'1511==`n'
}
foreach n of numlist 1/15 {
replace chpid2=pid`n' if h`y'1611==`n'
replace chage2=age`n' if h`y'1611==`n'
}
foreach n of numlist 1/15 {
replace chpid3=pid`n' if h`y'1711==`n'
replace chage3=age`n' if h`y'1711==`n'
}
foreach n of numlist 1/15 {
replace chpid4=pid`n' if h`y'1811==`n'
replace chage4=age`n' if h`y'1811==`n'
}
foreach n of numlist 1/15 {
replace chpid5=pid`n' if h`y'1911==`n'
replace chage5=age`n' if h`y'1911==`n'
}

* Number of private education lessons (For years 6, 12-20: whether taking private education or not)
rename h`y'1513 ifprivedu
recode ifprivedu 2=0

* total costs and number of private education per child
local i=1
foreach cost in h`y'1515 h`y'1615 h`y'1715 h`y'1815 h`y'1915 { 
capture confirm variable `cost' 
if !_rc {
rename `cost' edu_totcost`i'
local ++i
}
}
recode edu_totcost*(-1=.)

* number of children
rename h`y'1502 sib_numb_before_college // missing or 1-5 (there is no zero)
//rename h`y'2002 sib_numb_college

* drop unnecessary variables
keep hhid`y' ch* edu_totcost* sib* ifprivedu

* reshape
reshape long chpid chage edu_totcost, i(hhid`y')

drop if chpid==.

* sibling order (based on age)
gsort hhid`y' -chage
by hhid`y': gen sib_order = _n

* drop weird answers regarding number of children
by hhid`y': gen temp = _N
drop if temp~=sib_numb_before_college
drop temp

by hhid`y': egen sib_max = max(sib_order)
drop if sib_max~=sib_numb_before_college
drop sib_max

* dealing with missing observations
replace edu_totcost=0 if edu_totcost==. & ifprivedu==0

//sum edu_totcost

keep hhid`y' chpid chage edu_totcost sib_order
rename hhid`y' hhid

save temp_educost_detail`y', replace


*******************
* from 7th survey 
*******************
foreach y of num 7/20 {

if `y'<10 {
local y "0`y'"
}

use "$folder\KLIPS\klips`y'h_i", clear

keep if hwave`y'==1

/*=================================*/	
/* education expenditure per child */
/*=================================*/

* age
local k=1
foreach age of varlist h`y'0361-h`y'0375 {
rename `age' age`k'
local ++k
}
* personal id
local l=1
foreach pid of varlist h`y'0221-h`y'0235 {
rename `pid' pid`l'
local ++l
}
* max # of children under investigation = 8
foreach n of numlist 1/8 {
gen chpid`n'=.
gen chage`n'=.
}
* variables for each child
foreach n of numlist 1/15 {
replace chpid1=pid`n' if h`y'1511==`n'
replace chage1=age`n' if h`y'1511==`n'
}
foreach n of numlist 1/15 {
replace chpid2=pid`n' if h`y'1611==`n'
replace chage2=age`n' if h`y'1611==`n'
}
foreach n of numlist 1/15 {
replace chpid3=pid`n' if h`y'1711==`n'
replace chage3=age`n' if h`y'1711==`n'
}
foreach n of numlist 1/15 {
replace chpid4=pid`n' if h`y'1811==`n'
replace chage4=age`n' if h`y'1811==`n'
}
foreach n of numlist 1/15 {
replace chpid5=pid`n' if h`y'1911==`n'
replace chage5=age`n' if h`y'1911==`n'
}
foreach n of numlist 1/15 {
replace chpid6=pid`n' if h`y'2011==`n'
replace chage6=age`n' if h`y'2011==`n'
}
foreach n of numlist 1/15 {
replace chpid7=pid`n' if h`y'2021==`n'
replace chage7=age`n' if h`y'2021==`n'
}
foreach n of numlist 1/15 {
replace chpid8=pid`n' if h`y'2031==`n'
replace chage8=age`n' if h`y'2031==`n'
}

* type of private education
local i=1
foreach type1 in h`y'1516 h`y'1616 h`y'1716 h`y'1816 h`y'1916 {
capture confirm variable `type1' 
if !_rc {
rename `type1' type1`i'
local ++i
}
}
local i=1
foreach type2 in h`y'1520 h`y'1620 h`y'1720 h`y'1820 h`y'1920 {
capture confirm variable `type2' 
if !_rc {
rename `type2' type2`i'
local ++i
}
}
local i=1
foreach type3 in h`y'1524 h`y'1624 h`y'1724 h`y'1824 h`y'1924 {
capture confirm variable `type3' 
if !_rc {
rename `type3' type3`i'
local ++i
}
}
local i=1
foreach type4 in h`y'1528 h`y'1628 h`y'1728 h`y'1828 h`y'1928 {
capture confirm variable `type4' 
if !_rc {
rename `type4' type4`i'
local ++i
}
}
local i=1
foreach type5 in h`y'1532 h`y'1632 h`y'1732 h`y'1832 h`y'1932 {
capture confirm variable `type5' 
if !_rc {
rename `type5' type5`i'
local ++i
}
}
local i=1
foreach type6 in h`y'1536 h`y'1636 h`y'1736 h`y'1836 h`y'1936 {
capture confirm variable `type6' 
if !_rc {
rename `type6' type6`i'
local ++i
}
}
local i=1
foreach type7 in h`y'1538 h`y'1638 h`y'1738 h`y'1838 h`y'1938 {
capture confirm variable `type7' 
if !_rc {
rename `type7' type7`i'
local ++i
}
}
local i=1
foreach type8 in h`y'1540 h`y'1640 h`y'1740 h`y'1840 h`y'1940 {
capture confirm variable `type8' 
if !_rc {
rename `type8' type8`i'
local ++i
}
}
* cost of private education
local i=1
foreach cost1 in h`y'1519 h`y'1619 h`y'1719 h`y'1819 h`y'1919 {
capture confirm variable `cost1' 
if !_rc {
rename `cost1' cost1`i'
local ++i
}
}
local i=1
foreach cost2 in h`y'1523 h`y'1623 h`y'1723 h`y'1823 h`y'1923 {
capture confirm variable `cost2' 
if !_rc {
rename `cost2' cost2`i'
local ++i
}
}
local i=1
foreach cost3 in h`y'1527 h`y'1627 h`y'1727 h`y'1827 h`y'1927 {
capture confirm variable `cost3' 
if !_rc {
rename `cost3' cost3`i'
local ++i
}
}
local i=1
foreach cost4 in h`y'1531 h`y'1631 h`y'1731 h`y'1831 h`y'1931 {
capture confirm variable `cost4' 
if !_rc {
rename `cost4' cost4`i'
local ++i
}
}
local i=1
foreach cost5 in h`y'1535 h`y'1635 h`y'1735 h`y'1835 h`y'1935 {
capture confirm variable `cost5' 
if !_rc {
rename `cost5' cost5`i'
local ++i
}
}
local i=1
foreach cost6 in h`y'1537 h`y'1637 h`y'1737 h`y'1837 h`y'1937 {
capture confirm variable `cost6' 
if !_rc {
rename `cost6' cost6`i'
local ++i
}
}
local i=1
foreach cost7 in h`y'1539 h`y'1639 h`y'1739 h`y'1839 h`y'1939 {
capture confirm variable `cost7' 
if !_rc {
rename `cost7' cost7`i'
local ++i
}
}
local i=1
foreach cost8 in h`y'1541 h`y'1641 h`y'1741 h`y'1841 h`y'1941 {
capture confirm variable `cost8' 
if !_rc {
rename `cost8' cost8`i'
local ++i
}
}

* Number of private education lessons (For years 6 and 12-20: whether taking private education or not)
if `y'<=11 {
	rename h`y'1514 ifprivedu
	recode ifprivedu 1/9=1
}
if `y'>=12 {
	rename h`y'1513 ifprivedu
	recode ifprivedu 2=0
}

* number of children
rename h`y'1502 sib_numb_before_college // missing or 1-5 (there is no zero)
rename h`y'2002 sib_numb_college

* drop unnecessary variables
keep hhid`y' ch* type* cost* sib* ifprivedu

* reshape
#delimit ;
reshape long 
chpid chage 
type1 cost1 type2 cost2 type3 cost3 type4 cost4 type5 cost5 type6 cost6 type7 cost7 type8 cost8 
, i(hhid`y');
#delimit cr

drop if chpid==.

* sibling order (based on age)
gsort hhid`y' -chage
by hhid`y': gen sib_order = _n

* drop weird answers regarding number of children
by hhid`y': gen temp = _N
egen sib_numb_total = rowtotal(sib_numb_before_college sib_numb_college), missing
drop if temp~=sib_numb_total
drop temp

by hhid`y': egen sib_max = max(sib_order)
drop if sib_max~=sib_numb_total
drop sib_max sib_numb_total

* total costs and number of private education per child
recode cost*(-1=.)
egen edu_totcost=rowtotal(cost*),missing /*expenditures for private education*/

egen edu_numb=anycount(type*), values(1/21) /*private education types; 0: parents*/


* dealing with missing observations
replace edu_totcost=0 if edu_totcost==. & (ifprivedu==0 | edu_numb==0) & _j<6 // _j<6 means pre-college


keep hhid`y' chpid chage edu_totcost sib_order
rename hhid`y' hhid

save temp_educost_detail`y', replace
}


/*=======*/	 
/* Merge */
/*=======*/

use temp_educost_detail03.dta, clear
gen year=3
forval y=4/20 {
if `y'<10 {
local y "0`y'"
}
append using temp_educost_detail`y'.dta
replace year=`y' if year==.
}
order hhid chpid year


egen id = group(hhid chpid)

bys id year: drop if _N>1 // there are some mistakes in responses

xtset id year

* create a wide type data file
drop id
reshape wide chpid chage edu_totcost, i(hhid year) j(sib_order)  

label var hhid "household id"
label var year "1-20 (1998-2017)"
forval x=1/5 {
label var chpid`x' "child`x' personal id"
label var chage`x' "child`x' age"
label var edu_totcost`x' "child`x' private education costs"
}

}

save data_educost_detail_wide.dta, replace


quietly {
forval y=3/20 { //remove temporary files
if `y'<10 {
local y "0`y'"
}
erase temp_educost_detail`y'.dta
}
}



********************************************************************************
* Additional info about children's educational stages
********************************************************************************
quietly {

forval y=1/20 {  

local n=`y'
if `y'<10 {
local y "0`y'"
}

use "$folder\KLIPS\klips`y'h_i.dta", clear // `y'th survey data

keep if hwave`y'==1 // households participating in `y'th survey
gen year=`y'


local vlist "hhid* year" // basic variables for each household

* add following varialbes if they exist
foreach x of numlist 0261/0275 0361/0375 {
	local newx "0`x'"
	capture confirm variable h`y'`newx'
	if !_rc {
			local vlist "`vlist' h`y'`newx'"
	}
}

keep `vlist'


gen child_elem = 0
gen child_middle = 0
gen child_high = 0

forvalue i=1/15 {
local a=`i'+60
gen age_child_`i'=h`y'03`a' 
replace age_child_`i'=. if (h`y'02`a'<11 | h`y'02`a'>19)

replace child_elem=1 if age_child_`i'>=7 & age_child_`i'<=12
replace child_middle=1 if age_child_`i'>=13 & age_child_`i'<=15
replace child_high=1 if age_child_`i'>=16 & age_child_`i'<=18
}

* save
rename hhid`y' hhid
keep hhid year child_elem child_middle child_high

save temp`y'.dta, replace
}


use temp01.dta, clear
forval y=2/20 {
if `y'<10 {
local y "0`y'"
}
append using temp`y'.dta
}

label var hhid "household id"
label var year "1-20 (1998-2017)"
label var child_elem "elementary school indicator"
label var child_middle "middle school indicator"
label var child_high "high school indicator"

}

save children_school.dta, replace

qui forval y=1/20 {
if `y'<10 {
local y "0`y'"
}
erase temp`y'.dta
}




********************************************************************************
********************************************************************************
* PEES micro-data cleaning
********************************************************************************
********************************************************************************

quietly {

* 2009-2011

foreach y in 2009 2010 2011 { 

use "$folder\PEES/`y'_priv_edu.dta", clear

keep v2 v3 v19 v31 year

rename v2 province
rename v3 school
rename v19 hh_income
rename v31 priv_edu_cost

//describe // check variable type
//label list

destring priv_edu_cost, replace

* modify province to match to KLIPS
recode province (11=1) (21=2) (22=3) (23=5) (24=6) (25=4) (26=7) (31=8) (32=9) ///
                (33=1) (34=11) (35=12) (36=13) (37=14) (38=15) (39=16)
 
label define prov 1 "Seoul" 2 "Busan" 3 "Daegu" 4 "Daejeon" 5 "Incheon" 6 "Gwangju" 7 "Ulsan" /// 
          8 "Gyeonggi" 9 "Gwangwon" 10 "Chungbook" 11 "Chungnam" 12 "Jeonbook" 13 "Jeonnam" ///
		  14 "Gyeongbook" 15 "Gyeongnam" 16 "Jeju" 19 "Sejong"

label values province prov

* modify value labels to English
label define v3CD 1 "elementary", modify
label define v3CD 2 "middle", modify
label define v3CD 3 "high(general)", modify
label define v3CD 4 "high(occupational)", modify
label values school v3CD

label define v19CD 1 "0-1M won", modify
label define v19CD 2 "1-1.99M won", modify
label define v19CD 3 "2-2.99M won", modify
label define v19CD 4 "3-3.99M won", modify
label define v19CD 5 "4-4.99M won", modify
label define v19CD 6 "5-5.99M won", modify
label define v19CD 7 "6-6.99M won", modify
label define v19CD 8 "7M-inf. won", modify
label values hh_income v19CD

save "$folder\PEES/`y'_priv_edu_mod.dta", replace
}


* 2012 and 2014

foreach y in 2012 2014 {

use "$folder\PEES/`y'_priv_edu.dta", clear

keep v2 v3 v19 v30 year

rename v2 province
rename v3 school
rename v19 hh_income
rename v30 priv_edu_cost

//describe // check variable type
//label list

* if necessary
destring province school hh_income, replace

* modify province to match to KLIPS
recode province (11=1) (21=2) (22=3) (23=5) (24=6) (25=4) (26=7) (31=8) (32=9) ///
                (33=1) (34=11) (35=12) (36=13) (37=14) (38=15) (39=16)
 
label define prov 1 "Seoul" 2 "Busan" 3 "Daegu" 4 "Daejeon" 5 "Incheon" 6 "Gwangju" 7 "Ulsan" /// 
          8 "Gyeonggi" 9 "Gwangwon" 10 "Chungbook" 11 "Chungnam" 12 "Jeonbook" 13 "Jeonnam" ///
		  14 "Gyeongbook" 15 "Gyeongnam" 16 "Jeju" 19 "Sejong"

label values province prov

drop if province==29

* modify value labels to English
label define v3CD 1 "elementary", modify
label define v3CD 2 "middle", modify
label define v3CD 3 "high(general)", modify
label define v3CD 4 "high(occupational)", modify
label values school v3CD

label define v19CD 1 "0-1M won", modify
label define v19CD 2 "1-1.99M won", modify
label define v19CD 3 "2-2.99M won", modify
label define v19CD 4 "3-3.99M won", modify
label define v19CD 5 "4-4.99M won", modify
label define v19CD 6 "5-5.99M won", modify
label define v19CD 7 "6-6.99M won", modify
label define v19CD 8 "7M-inf. won", modify
label values hh_income v19CD

save "$folder\PEES/`y'_priv_edu_mod.dta", replace
}

* 2013

use "$folder\PEES/2013_priv_edu.dta", clear

keep v2 v3 v19 v30 year

rename v2 province
rename v3 school
rename v19 hh_income
rename v30 priv_edu_cost

replace priv_edu_cost=0 if priv_edu_cost==.

destring province school hh_income, replace

* modify province to match to KLIPS
recode province (11=1) (21=2) (22=3) (23=5) (24=6) (25=4) (26=7) (31=8) (32=9) ///
                (33=1) (34=11) (35=12) (36=13) (37=14) (38=15) (39=16)
 
label define prov 1 "Seoul" 2 "Busan" 3 "Daegu" 4 "Daejeon" 5 "Incheon" 6 "Gwangju" 7 "Ulsan" /// 
          8 "Gyeonggi" 9 "Gwangwon" 10 "Chungbook" 11 "Chungnam" 12 "Jeonbook" 13 "Jeonnam" ///
		  14 "Gyeongbook" 15 "Gyeongnam" 16 "Jeju" 19 "Sejong"

label values province prov

drop if province==29

* modify value labels to English
label define v3CD 1 "elementary", modify
label define v3CD 2 "middle", modify
label define v3CD 3 "high(general)", modify
label define v3CD 4 "high(occupational)", modify
label values school v3CD

label define v19CD 1 "0-1M won", modify
label define v19CD 2 "1-1.99M won", modify
label define v19CD 3 "2-2.99M won", modify
label define v19CD 4 "3-3.99M won", modify
label define v19CD 5 "4-4.99M won", modify
label define v19CD 6 "5-5.99M won", modify
label define v19CD 7 "6-6.99M won", modify
label define v19CD 8 "7M-inf. won", modify
label values hh_income v19CD

save "$folder\PEES/2013_priv_edu_mod.dta", replace

* 2015-2016

foreach y in 2015 2016 {

use "$folder\PEES/`y'_priv_edu.dta", clear

keep v2 v3 v29 v30 year

rename v2 province
rename v3 school
rename v29 hh_income
rename v30 priv_edu_cost

//describe // check variable type
//label list

* if necessary
//destring province school hh_income, replace

* modify province to match to KLIPS
recode province (11=1) (21=2) (22=3) (23=5) (24=6) (25=4) (26=7) (31=8) (32=9) ///
                (33=1) (34=11) (35=12) (36=13) (37=14) (38=15) (39=16)
 
label define prov 1 "Seoul" 2 "Busan" 3 "Daegu" 4 "Daejeon" 5 "Incheon" 6 "Gwangju" 7 "Ulsan" /// 
          8 "Gyeonggi" 9 "Gwangwon" 10 "Chungbook" 11 "Chungnam" 12 "Jeonbook" 13 "Jeonnam" ///
		  14 "Gyeongbook" 15 "Gyeongnam" 16 "Jeju" 19 "Sejong"

label values province prov

drop if province==29

* modify value labels to English
label define v3CD 1 "elementary", modify
label define v3CD 2 "middle", modify
label define v3CD 3 "high(general)", modify
label define v3CD 4 "high(occupational)", modify
label values school v3CD

label define v19CD 1 "0-1M won", modify
label define v19CD 2 "1-1.99M won", modify
label define v19CD 3 "2-2.99M won", modify
label define v19CD 4 "3-3.99M won", modify
label define v19CD 5 "4-4.99M won", modify
label define v19CD 6 "5-5.99M won", modify
label define v19CD 7 "6-6.99M won", modify
label define v19CD 8 "7M-inf. won", modify
label values hh_income v19CD

save "$folder\PEES/`y'_priv_edu_mod.dta", replace
}

* 2017-2018

foreach y in 2017 2018 {
use "$folder\PEES/`y'_priv_edu.dta", clear

keep v2 v3 v29 v30 year

rename v2 province
rename v3 school
rename v29 hh_income
rename v30 priv_edu_cost

//describe // check variable type
//label list

* if necessary
//destring province school grade father_* mother_* parents_work hh_income, replace

* modify province to match to KLIPS
recode province (11=1) (21=2) (22=3) (23=5) (24=6) (25=4) (26=7) (31=8) (32=9) ///
                (33=1) (34=11) (35=12) (36=13) (37=14) (38=15) (39=16)
 
label define prov 1 "Seoul" 2 "Busan" 3 "Daegu" 4 "Daejeon" 5 "Incheon" 6 "Gwangju" 7 "Ulsan" /// 
          8 "Gyeonggi" 9 "Gwangwon" 10 "Chungbook" 11 "Chungnam" 12 "Jeonbook" 13 "Jeonnam" ///
		  14 "Gyeongbook" 15 "Gyeongnam" 16 "Jeju" 19 "Sejong"

label values province prov

drop if province==29

* modify value labels to English
label define v3CD 1 "elementary", modify
label define v3CD 2 "middle", modify
label define v3CD 3 "high(general)", modify
label define v3CD 4 "high(occupational)", modify
label values school v3CD

label define v19CD 1 "0-1.99M won", modify
label define v19CD 2 "2-2.99M won", modify
label define v19CD 3 "3-3.99M won", modify
label define v19CD 4 "4-4.99M won", modify
label define v19CD 5 "5-5.99M won", modify
label define v19CD 6 "6-6.99M won", modify
label define v19CD 7 "7-7.99M won", modify
label define v19CD 8 "8M-inf. won", modify
label values hh_income v19CD

save "$folder\PEES/`y'_priv_edu_mod.dta", replace
}

* append all files

use "$folder\PEES/2009_priv_edu_mod.dta", clear

forval y = 2010/2018 { 
append using "$folder\PEES/`y'_priv_edu_mod.dta"
}

gen year_num = year
replace year = year-1997

label var year "1-20 (1998-2017)"
label var year_num "1998-2017"
label var province "province"
label var school "school level"
label var hh_income "household income"
label var priv_edu_cost "private education costs"

}

save "$folder\priv_edu_mod_merged.dta", replace


qui forval y=2009/2018 { 
erase "$folder\PEES/`y'_priv_edu_mod.dta"
}



***************************************
* prepare data for merge to KLIPS data
***************************************
quietly {
	
* province average
use priv_edu_mod_merged.dta, replace

keep province year school priv_edu_cost hh_income

collapse (mean) priv_edu_cost if school==2, by(province year)
rename priv_edu_cost micro_priv_edu_all

save temp_avg1.dta, replace

* top category 5, 6, 7, and 8
use priv_edu_mod_merged.dta, replace

keep province year school priv_edu_cost hh_income

collapse (mean) priv_edu_cost if school==2 & hh_income>=5, by(province year)
rename priv_edu_cost micro_priv_edu_top4

save temp_avg2.dta, replace

* top category 7, and 8
use priv_edu_mod_merged.dta, replace

keep province year school priv_edu_cost hh_income

collapse (mean) priv_edu_cost if school==2 & hh_income>=7, by(province year)
rename priv_edu_cost micro_priv_edu_top2

save temp_avg3.dta, replace

* top category 8
use priv_edu_mod_merged.dta, replace

keep province year school priv_edu_cost hh_income 

collapse (mean) priv_edu_cost if school==2 & hh_income>=8, by(province year)
rename priv_edu_cost micro_priv_edu_top1

save temp_avg4.dta, replace

* merge
use temp_avg1.dta, replace

merge 1:1 province year using temp_avg2
drop _merge

merge 1:1 province year using temp_avg3
drop _merge

merge 1:1 province year using temp_avg4
drop _merge

}

save micro_priv_edu_data.dta, replace

qui forval t=1/4 {
	erase temp_avg`t'.dta  
}


********************************************************************************
* merge PEES regional averages to KLIPS data
********************************************************************************

quietly {

use data_clean.dta, replace

* microdata on private education
merge m:1 year province using micro_priv_edu_data.dta
drop if _merge==2
drop _merge

}

save data_clean.dta, replace

erase micro_priv_edu_data.dta


********************************************************************************
********************************************************************************
* Data cleaning for intergenerational income persistence
********************************************************************************
********************************************************************************

quietly {
	
* children's income from personal data

forval y=1/20 {  

local n=`y'
if `y'<10 {
local y "0`y'"
}

use "$folder\KLIPS\klips`y'h_i.dta", clear // `y'th survey data

keep if hwave`y'==1 // households participating in `y'th survey

keep hhid`y' h`y'0221-h`y'0235 h`y'0261-h`y'0275 h`y'0361-h`y'0375 

local l=1
foreach pid of varlist h`y'0221-h`y'0235 {
rename `pid' pid`l'
local ++l
}
local i=1
foreach rel of varlist h`y'0261-h`y'0275 {
rename `rel' rel`i'
local ++i
}
local k=1
foreach age of varlist h`y'0361-h`y'0375 {
rename `age' age`k'
local ++k
}

reshape long pid rel age, i(hhid`y')

drop _j
drop if pid==.
keep if rel>=11 & rel<=19
drop rel

gen year=`y'

merge 1:1 hhid`y' pid using "$folder\KLIPS\klips`y'p_i.dta", keepusing(p`y'1642  p`y'1672) // p`y'1642 (salary worker) p`y'1672 (non-salary worker)
keep if _merge==3
drop _merge

recode p`y'1642 -1=. 
recode p`y'1672 -1=.

egen inc_child = rowtotal(p`y'1642  p`y'1672), missing

drop if inc_child==.

rename hhid`y' hhid

keep hhid pid age year inc_child

save temp`y'.dta, replace

}

use temp01.dta, clear
forval y=2/20 {
if `y'<10 {
local y "0`y'"
}
append using temp`y'.dta
}

label var hhid "household id"
label var pid "personal id"
label var age "age"
label var year "1-20 (1998-2017)"
label var inc_child "child earnings"

}

save intergeneration.dta, replace 

qui forval y=1/20 {
if `y'<10 {
local y "0`y'"
}
erase temp`y'.dta
}



********************************************************************************
********************************************************************************
* KLIPS data cleaning for the additional survey regarding time use
********************************************************************************
********************************************************************************

quietly {

*******************************
* hours for child care and work
*******************************

use "$folder\KLIPS\klips17a.dta", clear

sort pid

gen caretime = .
gen worktime = .
gen working_day = .

local N = _N

quietly forval i = 1/`N' {

	local t1 = 0
	local t2 = 0

	forval x = 177504/177551 { // activity by 30 minutes for a day 
	
		if a`x'[`i']==7 {  // caretime
			local t1 = `t1' + 1 
		}
		else if a`x'[`i']==4 {  // worktime
			local t2 = `t2' + 1 
		}
	}
	
	replace caretime = `t1'*0.5 if _n==`i' & a177553[`i']==1  // a177552:work-day=1,holiday=2; a177553:regular=1,non-regular=2
	replace worktime = `t2'*0.5 if _n==`i' & a177553[`i']==1  // a177552:work-day=1,holiday=2; a177553:regular=1,non-regular=2
	replace working_day = (a177552==1) if _n==`i'

}

keep pid *time working_day
drop if caretime==.

**********************************
* merge other personal information
**********************************

merge 1:1 pid using "$folder\KLIPS\klips17p_i.dta", ///
	keepusing(hhid17 p170102 p170101) 
keep if _merge==3
drop _merge

rename hhid17 hhid
label var hhid "household id"

* childcare time // p170102==10|20 house head or spouse. p170101=1male,2female
gen caretime_f = caretime if (p170102==10 |  p170102==20) & p170101==2 // female head
gen caretime_m = caretime if (p170102==10 |  p170102==20) & p170101==1 // male head

collapse (sum) caretime_f caretime_m, by(hhid)

label var caretime_f "female head child care hours"
label var caretime_m "male head child care hours"

* merge other information
merge 1:m hhid using data_clean.dta, ///
	keepusing(year edu* n_child* *age_child) 
drop if _merge==2
drop _merge

keep if year==17

}

save timeuse_merge.dta, replace


********************************************************************************
********************************************************************************
* Clean up the Korean Time Use Survey data
********************************************************************************
********************************************************************************

quietly {
	
use "$folder\KTUS\KTUS_2009.dta", clear

* rename variables
rename 가구일련번호 hid
rename 가구원번호 pid
rename 가구주관계코드 householder
rename 연령코드 agecode
rename 교육정도코드 edu_level
rename 교육재학코드 edu_state
rename 월평균소득구간코드 income
rename 성별 sex
foreach h in 04 05 06 07 08 09 10 11 {
	foreach m in 00 10 20 30 40 50 {
	rename 주행동주행동오후`h'`m'시간대코드 activity`h'`m'pm
	label var activity`h'`m'pm "main activity at `h':`m'pm"
	}
}
keep hid pid householder age* edu* income activity* sex

label var hid "household id"
label var pid "personal id"
label var householder "relationship code"
label var agecode "age code"
label var edu_level "education level code"
label var edu_state "education status code"
label var income "household income code"
label var sex "sex code"

}

save KTUS_2009_selected.dta, replace
