

clear



* load data
use data_clean.dta, clear

label var educost_priv_month "private education (monthly, 10,000 KRW)"


* family with kids
drop if n_child_head==0


* select households with school age children
merge 1:1 hhid year using children_school
drop if _merge==2
drop _merge
global elementary "child_elem==1"
global middle "child_middle==1"
global high "child_high==1"

global sel_school "$middle"


* KLIPS income and expenditures are for the previous year 
sort hhid year
by hhid: gen new_inc = f.inc
by hhid: gen new_expenditure_month = f.expenditure_month
by hhid: gen new_educost_pub_month = f.educost_pub_month
by hhid: gen new_educost_priv_month = f.educost_priv_month

replace inc = new_inc
replace expenditure_month = new_expenditure_month
replace educost_pub_month = new_educost_pub_month
replace educost_priv_month = new_educost_priv_month


* control inflation (2012 price)
merge m:1 year using cpi.dta
drop if _merge==2
drop _merge

replace inc = inc*100/cpi
replace expenditure_month = expenditure_month*100/cpi
replace educost_pub_month = educost_pub_month*100/cpi
replace educost_priv_month = educost_priv_month*100/cpi

	
* education costs per child 
gen educost_priv_cap = educost_priv_month/n_child_head
gen educost_priv_cap_con = educost_priv_cap/expenditure_month


* regional averages 
gen region_priv_edu_mid_top1 = micro_priv_edu_top1	
gen region_priv_edu_mid_top2 = micro_priv_edu_top2	
gen region_priv_edu_mid_top4 = micro_priv_edu_top4

gen ln_region_priv_edu_mid_top1 = ln(region_priv_edu_mid_top1)
gen ln_region_priv_edu_mid_top2 = ln(region_priv_edu_mid_top2)
gen ln_region_priv_edu_mid_top4 = ln(region_priv_edu_mid_top4)


* Curfew dummies
gen curfew_mid10 = 0
gen curfew_mid11 = 0
gen curfew_mid12 = 0

* Seoul = 1
replace curfew_mid10 = 1 if province==1 & year>=11
replace curfew_mid11 = 1 if province==1 & year>=11
replace curfew_mid12 = 1 if province==1 & year>=11
* Busan = 2
replace curfew_mid10 = 1 if province==2 & year>=11
replace curfew_mid11 = 1 if province==2 & year>=11
replace curfew_mid12 = 1 if province==2 & year>=11
* Daegu = 3
replace curfew_mid10 = 1 if province==3 & year>=14
replace curfew_mid11 = 1 if province==3 & year>=14
replace curfew_mid12 = 1 if province==3 & year>=3
* Daejeon = 4
replace curfew_mid11 = 1 if province==4 & year>=12
replace curfew_mid12 = 1 if province==4 & year>=12
* Incheon = 5
replace curfew_mid10 = 1 if province==5 & year>=15
replace curfew_mid11 = 1 if province==5 & year>=15
replace curfew_mid12 = 1 if province==5 & year>=11
* Gwangju = 6
replace curfew_mid10 = 1 if province==6 & year>=11
replace curfew_mid11 = 1 if province==6 & year>=11
replace curfew_mid12 = 1 if province==6 & year>=11
* Ulsan = 7
replace curfew_mid12 = 1 if province==7 & year>=11
* Gyeonggi = 8
replace curfew_mid10 = 1 if province==8 & year>=14
replace curfew_mid11 = 1 if province==8 & year>=11
replace curfew_mid12 = 1 if province==8 & year>=11
* Gangwon = 9
replace curfew_mid11 = 1 if province==9 & year>=15
replace curfew_mid12 = 1 if province==9 & year>=4
* Chungbuk = 10
replace curfew_mid11 = 1 if province==10 & year>=10
replace curfew_mid12 = 1 if province==10 & year>=10
* Chungnam = 11
replace curfew_mid11 = 1 if province==11 & year>=15
replace curfew_mid12 = 1 if province==11 & year>=11
* Jeonbuk 
replace curfew_mid10 = 1 if province==12 & year>=15 
replace curfew_mid11 = 1 if province==12 & year>=12 
replace curfew_mid12 = 1 if province==12 & year>=12 
* Jeonnam = 13
replace curfew_mid10 = 1 if province==13 & year>=14
replace curfew_mid11 = 1 if province==13 & year>=14
replace curfew_mid12 = 1 if province==13 & year>=10	
* Gyeongbuk = 14
replace curfew_mid10 = 1 if province==14 & (year>=3 & year<=10)
replace curfew_mid11 = 1 if province==14 & year>=3
replace curfew_mid12 = 1 if province==14 & year>=3
* Gyeongnam = 15
replace curfew_mid11 = 1 if province==15 & year>=16
replace curfew_mid12 = 1 if province==15 & year>=11
* Jeju = 16
replace curfew_mid11 = 1 if province==16 & year>=15
replace curfew_mid12 = 1 if province==16 & year>=10


	
**********************
* prepare regressions
**********************
sort hhid year


gen loweduc = 0
replace loweduc = 1 if edu_head_m <= 5 & edu_head_f <= 5 


**********************
* Regression with IV
**********************

* new variables for parents' age ranges 
egen avg_age_parents = rowmean(age_head_f age_head_m)

* nearly equally grouped
recode avg_age_parents (16/35=1) (35.1/40=2) (40.1/45=3) (45.1/50=4) (50.1/55=5) (55.1/60=6) (60.1/95=7), generate(age_group)

* income group
gen group=.

qui forvalues i=2/18{
	qui forvalues j=1/7{
		xtile temp = inc if year==`i' & age_group==`j', nq(4)
		replace group = temp if year==`i' & age_group==`j'
		drop temp
	}
}

gen lowinc = 0
replace lowinc = 1 if group<=1
gen lowinc2 = 0
replace lowinc2 = 1 if group<=2



************************
* Regression options
************************

global curfew_selec "curfew_mid10 curfew_mid11" 

global dep_var "educost_priv_cap_con" 
									 
global hh_controls "inc i.edu_head_m i.edu_head_f i.age_group" 


*************************************************************
* private education spending by parents' income and education
*************************************************************

global test_period "(year>=3 & year<=11)"  // before curfews were introduced

* mean differences
mat meandiff = J(2,2,.)
mat colnames meandiff = high low
mat rownames meandiff = income education

qui su educost_priv_cap if lowinc2==0 & $test_period & $sel_school
mat meandiff[1,1] = r(mean)
su educost_priv_cap if lowinc2==1 & $test_period & $sel_school
mat meandiff[1,2] = r(mean)

qui su educost_priv_cap if lowedu==0 & $test_period & $sel_school
mat meandiff[2,1] = r(mean)

qui su educost_priv_cap if lowedu==1 & $test_period & $sel_school
mat meandiff[2,2] = r(mean)

mat meandiff=meandiff*10 // match the unit used in the text

mat list meandiff

* regression
qui reg educost_priv_cap lowinc2 i.province if $test_period & $sel_school, vce(cluster province)
mat b = e(b)*10  // match the unit used in the text
mat v= e(V)

mat tableA4 = J(3,3,.)
mat colnames tableA4 = b se N
mat rownames tableA4 = lowinc lowedu whole
mat tableA4[1,1]=b[1,1]
mat tableA4[1,2]=(v[1,1]^0.5)*10 // match the unit used in the text
mat tableA4[1,3]=e(N)

qui reg educost_priv_cap lowedu i.province if $test_period & $sel_school, vce(cluster province)
mat b = e(b)*10 // match the unit used in the text
mat v= e(V)
mat tableA4[2,1]=b[1,1]
mat tableA4[2,2]=(v[1,1]^0.5)*10 // match the unit used in the text
mat tableA4[2,3]=e(N)

qui su educost_priv_cap if $test_period & $sel_school
mat tableA4[3,1] = r(mean)*10 // match the unit used in the text

********************************************************************************
* Table A4
mat list tableA4

putexcel set output\Tables, sheet(Table_A4, replace) modify  // new
putexcel A1=matrix(tableA4), nformat(0.0) names  // new
********************************************************************************



********************************************************************************
* Regression using high-income HH in the 1st stage 
* From here to line 470 for Table 3
********************************************************************************

* select reference group
local cat_num = 2  // cat_num=1: Top 5%, cat_num=2: Top 15%, cat_num=4: Top 50%

* dependent variable
global left_var "ln_region_priv_edu_mid_top`cat_num'" 

* select period
global sel_period "(year>=12 & year<=18)"   // minimum length covering whole variations using PEES



* Low Income (1)
eststo Minc1_1: reg $left_var $curfew_selec $hh_controls i.province if lowinc2==1 & $sel_period & $sel_school, cluster(province)

boottest curfew_mid10, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse1 = V[1,1]^0.5
boottest curfew_mid11, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse2 = V[1,1]^0.5
mat bootse = (`bootse1',`bootse2')
mat colnames bootse = $curfew_selec
mat list bootse
estadd matrix bootse: Minc1_1

eststo Minc1_2: ivregress 2sls $dep_var ($left_var = $curfew_selec) $hh_controls i.province if lowinc2==1 & $sel_period & $sel_school, vce(cluster province) first

boottest $left_var, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
mat bootse = (V[1,1]^0.5)
mat colnames bootse = $left_var
mat list bootse
estadd matrix bootse: Minc1_2

estat firststage
mat F = r(singleresults) 
estadd scalar fstat=F[1,4]: Minc1_1

estadd local yearFE "No": Minc1_1
estadd local yearFE "No": Minc1_2
estadd local T_trend "No": Minc1_1
estadd local T_trend "No": Minc1_2

* Low Income (2)
eststo Minc2_1: reg $left_var $curfew_selec $hh_controls i.province year if lowinc2==1 & $sel_period & $sel_school, cluster(province)

boottest curfew_mid10, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse1 = V[1,1]^0.5
boottest curfew_mid11, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse2 = V[1,1]^0.5
mat bootse = (`bootse1',`bootse2')
mat colnames bootse = $curfew_selec
mat list bootse
estadd matrix bootse: Minc2_1

eststo Minc2_2: ivregress 2sls $dep_var ($left_var = $curfew_selec) $hh_controls i.province year if lowinc2==1 & $sel_period & $sel_school, vce(cluster province) first

boottest $left_var, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
mat bootse = (V[1,1]^0.5)
mat colnames bootse = $left_var
mat list bootse
estadd matrix bootse: Minc2_2

estat firststage
mat F = r(singleresults) 
estadd scalar fstat=F[1,4]: Minc2_1

estadd local yearFE "No": Minc2_1
estadd local yearFE "No": Minc2_2
estadd local T_trend "Yes": Minc2_1
estadd local T_trend "Yes": Minc2_2


* Low Income (3)
eststo Minc3_1: reg $left_var $curfew_selec $hh_controls i.province i.year if lowinc2==1 & $sel_period & $sel_school, cluster(province)

boottest curfew_mid10, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse1 = V[1,1]^0.5
boottest curfew_mid11, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse2 = V[1,1]^0.5
mat bootse = (`bootse1',`bootse2')
mat colnames bootse = $curfew_selec
mat list bootse
estadd matrix bootse: Minc3_1

eststo Minc3_2: ivregress 2sls $dep_var ($left_var = $curfew_selec) $hh_controls i.province i.year if lowinc2==1 & $sel_period & $sel_school, vce(cluster province) first

boottest $left_var, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
mat bootse = (V[1,1]^0.5)
mat colnames bootse = $left_var
mat list bootse
estadd matrix bootse: Minc3_2

estat firststage
mat F = r(singleresults) 
estadd scalar fstat=F[1,4]: Minc3_1

estadd local yearFE "Yes": Minc3_1
estadd local yearFE "Yes": Minc3_2
estadd local T_trend "No": Minc3_1
estadd local T_trend "No": Minc3_2


********************************************************************************
* Table 3 - Low Income
esttab Minc1_1 Minc1_2 Minc2_1 Minc2_2 Minc3_1 Minc3_2 using output\Table3.rtf, append keep($left_var $curfew_selec) ///
cells(b(fmt(3) star)  bootse(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats(T_trend yearFE fstat N, labels("T-trend" "Year FE" "F-stat" "Obs.") fmt(a3)) ///
mtitles("delta" "beta" "delta" "beta" "delta" "beta") collab(none) ///
addnotes("The wild bootstrap standard errors in parentheses." "* p<0.10, ** p<0.05, *** p<0.01") ///
title("Micro Data (top `cat_num' income categories) / Low Income")
********************************************************************************


* Low Educ (1)
eststo Medu1_1: reg $left_var $curfew_selec $hh_controls i.province if loweduc==1 & $sel_period & $sel_school, cluster(province)

boottest curfew_mid10, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse1 = V[1,1]^0.5
boottest curfew_mid11, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse2 = V[1,1]^0.5
mat bootse = (`bootse1',`bootse2')
mat colnames bootse = $curfew_selec
mat list bootse
estadd matrix bootse: Medu1_1

eststo Medu1_2: ivregress 2sls $dep_var ($left_var = $curfew_selec) $hh_controls i.province if loweduc==1 & $sel_period & $sel_school, vce(cluster province) first

boottest $left_var, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
mat bootse = (V[1,1]^0.5)
mat colnames bootse = $left_var
mat list bootse
estadd matrix bootse: Medu1_2

estat firststage
mat F = r(singleresults) 
estadd scalar fstat=F[1,4]: Medu1_1

estadd local yearFE "No": Medu1_1
estadd local yearFE "No": Medu1_2
estadd local T_trend "No": Medu1_1
estadd local T_trend "No": Medu1_2

* Low Educ (2)
eststo Medu2_1: reg $left_var $curfew_selec $hh_controls i.province year if loweduc==1 & $sel_period & $sel_school, cluster(province)

boottest curfew_mid10, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse1 = V[1,1]^0.5
boottest curfew_mid11, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse2 = V[1,1]^0.5
mat bootse = (`bootse1',`bootse2')
mat colnames bootse = $curfew_selec
mat list bootse
estadd matrix bootse: Medu2_1

eststo Medu2_2: ivregress 2sls $dep_var ($left_var = $curfew_selec) $hh_controls i.province year if loweduc==1 & $sel_period & $sel_school, vce(cluster province) first

boottest $left_var, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
mat bootse = (V[1,1]^0.5)
mat colnames bootse = $left_var
mat list bootse
estadd matrix bootse: Medu2_2

estat firststage
mat F = r(singleresults) 
estadd scalar fstat=F[1,4]: Medu2_1

estadd local yearFE "No": Medu2_1
estadd local yearFE "No": Medu2_2
estadd local T_trend "Yes": Medu2_1
estadd local T_trend "Yes": Medu2_2


* Low Educ (3)
eststo Medu3_1: reg $left_var $curfew_selec $hh_controls i.province i.year if loweduc==1 & $sel_period & $sel_school, cluster(province)

boottest curfew_mid10, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse1 = V[1,1]^0.5
boottest curfew_mid11, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse2 = V[1,1]^0.5
mat bootse = (`bootse1',`bootse2')
mat colnames bootse = $curfew_selec
mat list bootse
estadd matrix bootse: Medu3_1

eststo Medu3_2: ivregress 2sls $dep_var ($left_var = $curfew_selec) $hh_controls i.province i.year if loweduc==1 & $sel_period & $sel_school, vce(cluster province) first

boottest $left_var, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
mat bootse = (V[1,1]^0.5)
mat colnames bootse = $left_var
mat list bootse
estadd matrix bootse: Medu3_2

estat firststage
mat F = r(singleresults) 
estadd scalar fstat=F[1,4]: Medu3_1

estadd local yearFE "Yes": Medu3_1
estadd local yearFE "Yes": Medu3_2
estadd local T_trend "No": Medu3_1
estadd local T_trend "No": Medu3_2


********************************************************************************
* Table 3 - Low Education
esttab Medu1_1 Medu1_2 Medu2_1 Medu2_2 Medu3_1 Medu3_2 using output\Table3.rtf, append keep($left_var $curfew_selec) ///
cells(b(fmt(3) star)  bootse(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats(T_trend yearFE fstat N, labels("T-trend" "Year FE" "F-stat" "Obs.") fmt(a3)) ///
mtitles("delta" "beta" "delta" "beta" "delta" "beta") collab(none) ///
addnotes("The wild bootstrap standard errors in parentheses." "* p<0.10, ** p<0.05, *** p<0.01") ///
title("Micro Data (top `cat_num' income categories) / Low Education")
********************************************************************************





********************************************************************************
* From here for Table A5 
* The result doc files are saved automatically for each value of cat_num.
********************************************************************************

foreach num in 1 2 4 {
	
local cat_num = `num'  // cat_num=1: Top 5%, cat_num=2: Top 15%, cat_num=4: Top 50%
global left_var "ln_region_priv_edu_mid_top`cat_num'" 


* Low Income (1)
eststo Minc1_1: reg $left_var $curfew_selec $hh_controls i.province if lowinc2==1 & $sel_period & $sel_school, cluster(province)

boottest curfew_mid10, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse1 = V[1,1]^0.5
boottest curfew_mid11, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse2 = V[1,1]^0.5
mat bootse = (`bootse1',`bootse2')
mat colnames bootse = $curfew_selec
mat list bootse
estadd matrix bootse: Minc1_1

eststo Minc1_2: ivregress 2sls $dep_var ($left_var = $curfew_selec) $hh_controls i.province if lowinc2==1 & $sel_period & $sel_school, vce(cluster province) first

boottest $left_var, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
mat bootse = (V[1,1]^0.5)
mat colnames bootse = $left_var
mat list bootse
estadd matrix bootse: Minc1_2

estat firststage
mat F = r(singleresults) 
estadd scalar fstat=F[1,4]: Minc1_1

estadd local yearFE "No": Minc1_1
estadd local yearFE "No": Minc1_2

* Low Income (2)
eststo Minc2_1: reg $left_var $curfew_selec $hh_controls i.province i.year if lowinc2==1 & $sel_period & $sel_school, cluster(province)

boottest curfew_mid10, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse1 = V[1,1]^0.5
boottest curfew_mid11, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse2 = V[1,1]^0.5
mat bootse = (`bootse1',`bootse2')
mat colnames bootse = $curfew_selec
mat list bootse
estadd matrix bootse: Minc2_1

eststo Minc2_2: ivregress 2sls $dep_var ($left_var = $curfew_selec) $hh_controls i.province i.year if lowinc2==1 & $sel_period & $sel_school, vce(cluster province) first

boottest $left_var, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
mat bootse = (V[1,1]^0.5)
mat colnames bootse = $left_var
mat list bootse
estadd matrix bootse: Minc2_2

estat firststage
mat F = r(singleresults) 
estadd scalar fstat=F[1,4]: Minc2_1

estadd local yearFE "Yes": Minc2_1
estadd local yearFE "Yes": Minc2_2

********************************************************************************
* Table A5 - Low income
esttab Minc1_1 Minc1_2 Minc2_1 Minc2_2 using output\TableA5-`cat_num'.rtf, append keep($left_var $curfew_selec) ///
cells(b(fmt(3) star)  bootse(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats(yearFE fstat N, labels("Year FE" "F-stat" "Obs.") fmt(a3)) ///
mtitles("Low Inc 1st" "2nd-stage" "Low Inc 1st" "2nd-stage") collab(none) ///
addnotes("The wild bootstrap standard errors in parentheses." "* p<0.10, ** p<0.05, *** p<0.01") ///
title("Micro Data (top `cat_num' income categories) / Low Income")
********************************************************************************

* Low Educ (1)
eststo Medu1_1: reg $left_var $curfew_selec $hh_controls i.province if loweduc==1 & $sel_period & $sel_school, cluster(province)

boottest curfew_mid10, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse1 = V[1,1]^0.5
boottest curfew_mid11, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse2 = V[1,1]^0.5
mat bootse = (`bootse1',`bootse2')
mat colnames bootse = $curfew_selec
mat list bootse
estadd matrix bootse: Medu1_1

eststo Medu1_2: ivregress 2sls $dep_var ($left_var = $curfew_selec) $hh_controls i.province if loweduc==1 & $sel_period & $sel_school, vce(cluster province) first

boottest $left_var, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
mat bootse = (V[1,1]^0.5)
mat colnames bootse = $left_var
mat list bootse
estadd matrix bootse: Medu1_2

estat firststage
mat F = r(singleresults) 
estadd scalar fstat=F[1,4]: Medu1_1

estadd local yearFE "No": Medu1_1
estadd local yearFE "No": Medu1_2

* Low Educ (2)
eststo Medu2_1: reg $left_var $curfew_selec $hh_controls i.province i.year if loweduc==1 & $sel_period & $sel_school, cluster(province)

boottest curfew_mid10, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse1 = V[1,1]^0.5
boottest curfew_mid11, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
local bootse2 = V[1,1]^0.5
mat bootse = (`bootse1',`bootse2')
mat colnames bootse = $curfew_selec
mat list bootse
estadd matrix bootse: Medu2_1

eststo Medu2_2: ivregress 2sls $dep_var ($left_var = $curfew_selec) $hh_controls i.province i.year if loweduc==1 & $sel_period & $sel_school, vce(cluster province) first

boottest $left_var, cluster(province) nograph reps(999) level(95) seed(2023)
mat V = r(V)
mat bootse = (V[1,1]^0.5)
mat colnames bootse = $left_var
mat list bootse
estadd matrix bootse: Medu2_2

estat firststage
mat F = r(singleresults) 
estadd scalar fstat=F[1,4]: Medu2_1

estadd local yearFE "Yes": Medu2_1
estadd local yearFE "Yes": Medu2_2

********************************************************************************
* Table A5 - Low education
esttab Medu1_1 Medu1_2 Medu2_1 Medu2_2 using output\TableA5-`cat_num'.rtf, append keep($left_var $curfew_selec) ///
cells(b(fmt(3) star)  bootse(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
stats(yearFE fstat N, labels("Year FE" "F-stat" "Obs.") fmt(a3)) ///
mtitles("Low Edu 1st" "2nd-stage" "Low Edu 1st" "2nd-stage") collab(none) ///
addnotes("The wild bootstrap standard errors in parentheses." "* p<0.10, ** p<0.05, *** p<0.01") ///
title("Micro Data (top `cat_num' income categories) / Low Education")
********************************************************************************
}

