
clear



* open data
use priv_edu_mod_merged.dta, clear

* select the number of lags and variables
global lag_num = 4
global last_year = 2011+$lag_num
drop if year_num > $last_year

* control inflation (2012 price)
merge m:1 year using cpi.dta
drop if _merge==2
drop _merge

replace priv_edu_cost = priv_edu_cost*100/cpi

* gen log spending
gen ln_priv_edu_cost=ln(priv_edu_cost)


* gen year dummies
forval y = 2009/$last_year {
	gen i`y' = (year_num==`y')
}

* gen treatment dummies
gen itreat2011 = (province==3 | province==8 | province==13)
gen itreat2012 = (province==5 | province==9 | province==11 | province==12 | province==16)
gen itreat2013 = (province==15)
gen itreat2008 = (province==1 | province==2 | province==6 | province==10) 
gen inotreat = (province==7 | province==14)

drop if  province==4 


* (1) control: no treat + treatment in 2008

capture: drop icontrol
gen icontrol = (inotreat==1 | itreat2008==1)
capture: drop itreat
egen itreat = rowtotal(itreat2011 itreat2012 itreat2013), missing

* prepare figures
global fig_start = 1
global fig_end = 3+$lag_num

mat time = [2009 \ 2010 \ 2011 \ 2012 \ 2013 \ 2014 \ 2015]
mat colnames time = time
capture: drop time
svmat time, names(col)

mat b_treat=J(7,1,0)
mat lb_treat=J(7,1,0)
mat ub_treat=J(7,1,0)

mat b_control=J(7,1,0)
mat lb_control=J(7,1,0)
mat ub_control=J(7,1,0)

mat b_treat_boot=J(7,1,0)
mat lb_treat_boot=J(7,1,0)
mat ub_treat_boot=J(7,1,0)

mat b_control_boot=J(7,1,0)
mat lb_control_boot=J(7,1,0)
mat ub_control_boot=J(7,1,0)

* ols regression

* All households
reg ln_priv_edu_cost i2010 i2011 i2012 i2013 i2014 i2015 ///
(c.i2010 c.i2011 c.i2012 c.i2013 c.i2014 c.i2015)#c.itreat ///
i.province if school==2 & (itreat==1 | icontrol==1) 

* save estimated values
qui foreach x in 2010 2011 2012 2013 2014 2015 {

local col = `x'-2008

lincom c.i`x'#c.itreat + i`x'

mat b_treat[`col',1] = r(estimate)
mat lb_treat[`col',1] = r(lb)
mat ub_treat[`col',1] = r(ub)

lincom  i`x'

mat b_control[`col',1] = r(estimate)
mat lb_control[`col',1] = r(lb)
mat ub_control[`col',1] = r(ub)
}

* figure
mat result = [b_treat, lb_treat, ub_treat, b_control, lb_control, ub_control]
mat colnames result = b_treat lb_treat ub_treat b_control lb_control ub_control
capture: drop b_* lb_* ub_*
svmat result, names(col)

********************************************************************************
* Figure 2 and Figure A5-A
twoway connected b_treat time in $fig_start/$fig_end, color(midblue) lpattern(1) msymbol(d) ///
|| rarea ub_treat lb_treat time in $fig_start/$fig_end, color(midblue%10)  lwidth(*0.1) ///
|| connected b_control time in $fig_start/$fig_end, color(orange) lpattern(-) msymbol(o) lwidth(*1.5) /// ///
|| rarea ub_control lb_control time in $fig_start/$fig_end, color(orange%10) lwidth(*0.1) ///
yline(0, lwidth(thin) lpattern(dash) lcolor(black)) xline(2010.5, lwidth(thin) lpattern(dash) lcolor(black)) ///
 ylabel(-0.1(0.05)0.1,labsize(medlarge) nogrid) xlabel(2009(1)2015,labsize(medlarge) nogrid) ///
graphregion(fcolor(white) lcolor(white) lwidth(vvvthin) ifcolor(white) ilcolor(white) ilwidth(vvvthin)) ///
xtitle("Year", size(large)) ///
legend(cols(1) order(1 "Treatment" 3 "Control") position(7) ring(0) bmargin(small) size(medlarge))  scheme(cleanplots)

graph export output\Figure_2.pdf, replace    // new
graph export output\Figure_A5_A.pdf, replace    // new
********************************************************************************


* Bottom 50% income households
reg ln_priv_edu_cost i2010 i2011 i2012 i2013 i2014 i2015 ///
(c.i2010 c.i2011 c.i2012 c.i2013 c.i2014 c.i2015)#c.itreat ///
i.province if school==2 & (itreat==1 | icontrol==1) & hh_income<=4

* save estimated values
qui foreach x in 2010 2011 2012 2013 2014 2015 {

local col = `x'-2008

lincom c.i`x'#c.itreat + i`x'

mat b_treat[`col',1] = r(estimate)
mat lb_treat[`col',1] = r(lb)
mat ub_treat[`col',1] = r(ub)

lincom  i`x'

mat b_control[`col',1] = r(estimate)
mat lb_control[`col',1] = r(lb)
mat ub_control[`col',1] = r(ub)
}

* figure
mat result = [b_treat, lb_treat, ub_treat, b_control, lb_control, ub_control]
mat colnames result = b_treat lb_treat ub_treat b_control lb_control ub_control
capture: drop b_* lb_* ub_*
svmat result, names(col)

********************************************************************************
* Figure A5-B
twoway connected b_treat time in $fig_start/$fig_end, color(midblue) lpattern(1) msymbol(d) ///
|| rarea ub_treat lb_treat time in $fig_start/$fig_end, color(midblue%10)  lwidth(*0.1) ///
|| connected b_control time in $fig_start/$fig_end, color(orange) lpattern(-) msymbol(o) lwidth(*1.5) /// ///
|| rarea ub_control lb_control time in $fig_start/$fig_end, color(orange%10) lwidth(*0.1) ///
yline(0, lwidth(thin) lpattern(dash) lcolor(black)) xline(2010.5, lwidth(thin) lpattern(dash) lcolor(black)) ///
 ylabel(-0.1(0.05)0.1,labsize(medlarge) nogrid) xlabel(2009(1)2015,labsize(medlarge) nogrid) ///
graphregion(fcolor(white) lcolor(white) lwidth(vvvthin) ifcolor(white) ilcolor(white) ilwidth(vvvthin)) ///
xtitle("Year", size(large)) ///
legend(cols(1) order(1 "Treatment" 3 "Control") position(7) ring(0) bmargin(small) size(medlarge))  scheme(cleanplots)

graph export output\Figure_A5_B.pdf, replace    // new
********************************************************************************


* Top 50% income households
reg ln_priv_edu_cost i2010 i2011 i2012 i2013 i2014 i2015 ///
(c.i2010 c.i2011 c.i2012 c.i2013 c.i2014 c.i2015)#c.itreat ///
i.province if school==2 & (itreat==1 | icontrol==1) & hh_income>4

* save estimated values
qui foreach x in 2010 2011 2012 2013 2014 2015 {

local col = `x'-2008

lincom c.i`x'#c.itreat + i`x'

mat b_treat[`col',1] = r(estimate)
mat lb_treat[`col',1] = r(lb)
mat ub_treat[`col',1] = r(ub)

lincom  i`x'

mat b_control[`col',1] = r(estimate)
mat lb_control[`col',1] = r(lb)
mat ub_control[`col',1] = r(ub)
}

* figure
mat result = [b_treat, lb_treat, ub_treat, b_control, lb_control, ub_control]
mat colnames result = b_treat lb_treat ub_treat b_control lb_control ub_control
capture: drop b_* lb_* ub_*
svmat result, names(col)

********************************************************************************
* Figure A5-C
twoway connected b_treat time in $fig_start/$fig_end, color(midblue) lpattern(1) msymbol(d) ///
|| rarea ub_treat lb_treat time in $fig_start/$fig_end, color(midblue%10)  lwidth(*0.1) ///
|| connected b_control time in $fig_start/$fig_end, color(orange) lpattern(-) msymbol(o) lwidth(*1.5) /// ///
|| rarea ub_control lb_control time in $fig_start/$fig_end, color(orange%10) lwidth(*0.1) ///
yline(0, lwidth(thin) lpattern(dash) lcolor(black)) xline(2010.5, lwidth(thin) lpattern(dash) lcolor(black)) ///
 ylabel(-0.3(0.05)0,labsize(medlarge) nogrid) xlabel(2009(1)2015,labsize(medlarge) nogrid) ///
graphregion(fcolor(white) lcolor(white) lwidth(vvvthin) ifcolor(white) ilcolor(white) ilwidth(vvvthin)) ///
xtitle("Year", size(large)) ///
legend(cols(1) order(1 "Treatment" 3 "Control") position(7) ring(0) bmargin(small) size(medlarge))  scheme(cleanplots)

graph export output\Figure_A5_C.pdf, replace    // new
********************************************************************************




* Top 15% income households
reg ln_priv_edu_cost i2010 i2011 i2012 i2013 i2014 i2015 ///
(c.i2010 c.i2011 c.i2012 c.i2013 c.i2014 c.i2015)#c.itreat ///
i.province if school==2 & (itreat==1 | icontrol==1) & hh_income>=7

* save estimated values
qui foreach x in 2010 2011 2012 2013 2014 2015 {

local col = `x'-2008

lincom c.i`x'#c.itreat + i`x'

mat b_treat[`col',1] = r(estimate)
mat lb_treat[`col',1] = r(lb)
mat ub_treat[`col',1] = r(ub)

lincom  i`x'

mat b_control[`col',1] = r(estimate)
mat lb_control[`col',1] = r(lb)
mat ub_control[`col',1] = r(ub)
}

* figure
mat result = [b_treat, lb_treat, ub_treat, b_control, lb_control, ub_control]
mat colnames result = b_treat lb_treat ub_treat b_control lb_control ub_control
capture: drop b_* lb_* ub_*
svmat result, names(col)

********************************************************************************
* Figure A5-D
twoway connected b_treat time in $fig_start/$fig_end, color(midblue) lpattern(1) msymbol(d) ///
|| rarea ub_treat lb_treat time in $fig_start/$fig_end, color(midblue%10)  lwidth(*0.1) ///
|| connected b_control time in $fig_start/$fig_end, color(orange) lpattern(-) msymbol(o) lwidth(*1.5) /// ///
|| rarea ub_control lb_control time in $fig_start/$fig_end, color(orange%10) lwidth(*0.1) ///
yline(0, lwidth(thin) lpattern(dash) lcolor(black)) xline(2010.5, lwidth(thin) lpattern(dash) lcolor(black)) ///
 ylabel(-0.3(0.05)0,labsize(medlarge) nogrid) xlabel(2009(1)2015,labsize(medlarge) nogrid) ///
graphregion(fcolor(white) lcolor(white) lwidth(vvvthin) ifcolor(white) ilcolor(white) ilwidth(vvvthin)) ///
xtitle("Year", size(large)) ///
legend(cols(1) order(1 "Treatment" 3 "Control") position(7) ring(0) bmargin(small) size(medlarge))  scheme(cleanplots)

graph export output\Figure_A5_D.pdf, replace    // new
********************************************************************************
