
clear


****************************
* household's labor supply
****************************

use data_clean.dta, clear

sort hhid year

* age restriction
keep if age_head_f > 25 & age_head_f <= 50
keep if age_head_m > 25 & age_head_m <= 50

replace married_f=2 if married_f==. & age_head_m~=. & age_head_f~=.
replace hours_head_f = 0 if hours_head_f == . // set missing to zero to include the extensive margin
replace hours_head_m = 0 if hours_head_m == . 

* total hours
replace married_f=2 if married_f==. & age_head_m~=. & age_head_f~=.

gen tothrs = 0
replace tothrs = 0.5*hours_head_f + 0.5*hours_head_m if married_f == 2 // equal weights
replace tothrs = hours_head_f if married_f ~= 2
 
********************************************************************************
* household's labor supply
su tothrs

putexcel set output\Statistics, modify   // new
putexcel A13=("Working hours") B13=matrix(r(mean)), nformat(0.0)  // new
********************************************************************************


**********************************************************
* caretime Using timeuse data in KLIPS additional survey
**********************************************************

use timeuse_merge.dta, clear

su caretime_f if max_age_child < 18 
scalar t1 = r(mean)*7
disp t1

su caretime_m if max_age_child < 18 
scalar t2 = r(mean)*7
disp t2

su n_child_head if max_age_child < 18 
scalar nn = r(mean)

********************************************************************************
* average caretime
disp (t1+t2)*0.5/nn

putexcel A14=("Parental time per child (mother)") B14=t1, nformat(0.0)  // new
putexcel A15=("Parental time per child (father)") B15=t2, nformat(0.0)  // new
putexcel A16=("Average number of children") B16=nn, nformat(0.00)  // new
putexcel A17=("Parental time per child (average)") B17=((t1+t2)*0.5/nn), nformat(0.0)  // new
********************************************************************************


***********************************
* caretime / by parents' education
***********************************

mat result=J(4,4,.)
mat colnames result = young_college young_high any_college any_high
mat rownames result = mother n1 father n2 
 
qui ci means caretime_f if min_age_child <=5 & edu_head_f>=7
mat result[1,1] = r(mean)*7
mat result[2,1] = r(N)

qui ci means caretime_m if min_age_child <=5 & edu_head_m>=7
mat result[3,1] = r(mean)*7
mat result[4,1] = r(N)

qui ci means caretime_f if min_age_child <=5 & edu_head_f<7
mat result[1,2] = r(mean)*7
mat result[2,2] = r(N)

qui ci means caretime_m if min_age_child <=5 & edu_head_m<7
mat result[3,2] = r(mean)*7
mat result[4,2] = r(N)

qui ci means caretime_f if max_age_child <18 & edu_head_f>=7
mat result[1,3] = r(mean)*7
mat result[2,3] = r(N)

qui ci means caretime_m if max_age_child <18 & edu_head_m>=7
mat result[3,3] = r(mean)*7
mat result[4,3] = r(N)

qui ci means caretime_f if max_age_child <18 & edu_head_f<7
mat result[1,4] = r(mean)*7
mat result[2,4] = r(N)

qui ci means caretime_m if max_age_child <18 & edu_head_m<7
mat result[3,4] = r(mean)*7
mat result[4,4] = r(N)

********************************************************************************
* Table A8
mat list result

putexcel set output\Tables, sheet(Table_A8, replace) modify  // new
putexcel A1=matrix(result), nformat(0.0) names  // new
********************************************************************************

	